@@ -212,6 +212,7 @@ GtkWidget *combo_with_popdown(const gchar * setstring, GList * which_list, gint
 	GtkWidget *returnwidget;
 
 	returnwidget = gtk_combo_new();
+	gtk_combo_set_case_sensitive(GTK_COMBO(returnwidget),TRUE);
 	if (which_list != NULL) {
 		gtk_combo_set_popdown_strings(GTK_COMBO(returnwidget), which_list);
 	}
@@ -224,6 +225,7 @@ GtkWidget *combo_with_popdown(const gchar * setstring, GList * which_list, gint
 		gtk_editable_set_editable(GTK_EDITABLE(GTK_ENTRY(GTK_COMBO(returnwidget)->entry)), FALSE);
 	}
 	gtk_combo_disable_activate(GTK_COMBO(returnwidget));
+	gtk_entry_set_activates_default (GTK_ENTRY (GTK_COMBO (returnwidget)->entry), TRUE);
 	return returnwidget;
 }
 /**
@@ -569,7 +571,7 @@ static gboolean window_full_key_press_event_lcb(GtkWidget *widget,GdkEventKey *e
  * 	@position: #gint the gtk window position GTK_WIN_POS_NONE, GTK_WIN_POS_CENTER, GTK_WIN_POS_MOUSE
  * 	@borderwidth: #gint border width
  * 	@close_func: #GCallback the callback function when closing the window
- * 	@close_data: #gpointer data passed to the closefunc
+ * 	@close_data: #gpointer data passed to the closefunc, or NULL to pass the widget pointer as close data
  * @delete_on_escape: #gboolean if the escape key should close the dialog
  * @transientforparent: #GtkWidget* with the window to set this transient for, or NULL
  *
@@ -614,7 +616,7 @@ GtkWidget *window_full2(gchar * title, GtkWindowPosition position
  * 	@width: #gint the width of the scrolwin, -1 if default required
  * 	@height: #gint the height of the scrolwin, -1 if default required
  * 	@contents: #gchar* the initial contents of the textbox
- * 	@wrapmode: #GtkWrapMode the wrapmode for the TextView
+ * 	@wrapmode: #GtkWrapMode the wrapmode for the TextView GTK_WRAP_NONE,GTK_WRAP_CHAR,GTK_WRAP_WORD
  *
  * creates a textbuffer, a textview widget (stored in the textview pointer), 
  * puts that inside a scrolwin, adds the content and sets the size and returns
@@ -622,7 +624,7 @@ GtkWidget *window_full2(gchar * title, GtkWindowPosition position
  *
  * Return value: #GtkWidget* to the scolwin
  */
-GtkWidget *textview_buffer_in_scrolwin(GtkWidget **textview, gint width, gint height, gchar *contents, GtkWrapMode wrapmode) {
+GtkWidget *textview_buffer_in_scrolwin(GtkWidget **textview, gint width, gint height, const gchar *contents, GtkWrapMode wrapmode) {
 	GtkWidget *scrolwin;
 	GtkTextBuffer *textbuf;
 	
@@ -1255,6 +1257,7 @@ static void file_but_destroy(GtkObject *object, Tfilebut *fb) {
  * @which_entry: #GtkWidget* GTK_ENTRY where to put the filename
  * @win: #GtkWidget* the GTK_WINDOW where the button is placed
  * @full_pathname: #gint 1 or 0, if you want the full path or a relative path
+ * #bfwin: #Tbfwin, only required if you want a relative pathname
  *
  *	Create new "open file" button, that will put the string into an entry
  *
@@ -1345,7 +1348,7 @@ static void fs_ok_clicked_lcb(GtkWidget * widget, Tfileselect *fileselect)
 	window_destroy(GTK_WIDGET(fileselect->fs));
 }
 
-static void close_modal_window_lcb(GtkWidget * widget, gpointer window)
+void close_modal_window_lcb(GtkWidget * widget, gpointer window)
 {
 	DEBUG_MSG("close_modal_window_lcb, widget=%p, window=%p\n", widget, window);
 	gtk_main_quit();
