@@ -47,9 +47,7 @@
 #include "preferences.h" /* open_preferences_cb */
 #include "outputbox.h" /* init_outputbox() */
 #include "fref.h"
-#ifdef BOOKMARKS
 #include "bookmark.h"
-#endif /* BOOKMARKS */
 #include "project.h"
 
 #ifdef HAVE_LIBASPELL
@@ -149,6 +147,7 @@ void notebook_changed(Tbfwin *bfwin, gint newpage) {
 	flush_queue();
 
 	doc_activate(bfwin->current_document);
+/*	bmark_adjust_visible(bfwin);*/
 }
 
 gboolean switch_to_document_by_index(Tbfwin *bfwin,gint index) {
@@ -205,9 +204,7 @@ GtkWidget *left_panel_build(Tbfwin *bfwin) {
 	GtkWidget *fileb;
 	GtkWidget *left_notebook = gtk_notebook_new();
 	GtkWidget *fref;
-#ifdef BOOKMARKS
-   GtkWidget *bmarks;
-#endif /* BOOKMARKS */
+	GtkWidget *bmarks;
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(left_notebook),main_v->props.leftpanel_tabposition);
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(left_notebook), TRUE);
 	gtk_notebook_set_show_border(GTK_NOTEBOOK(left_notebook), FALSE);
@@ -216,14 +213,10 @@ GtkWidget *left_panel_build(Tbfwin *bfwin) {
 	gtk_notebook_popup_enable(GTK_NOTEBOOK(left_notebook));
 	fileb = filebrowser_init(bfwin);
 	fref = fref_gui(bfwin);
-#ifdef BOOKMARKS
 	bmarks = bmark_gui(bfwin);
-#endif /* BOOKMARKS */	
-	gtk_notebook_append_page(GTK_NOTEBOOK(left_notebook),fileb,new_pixmap(105));
-	gtk_notebook_append_page(GTK_NOTEBOOK(left_notebook),fref,new_pixmap(106));
-#ifdef BOOKMARKS	
-	gtk_notebook_append_page(GTK_NOTEBOOK(left_notebook),bmarks,NULL);
-#endif /* BOOKMARKS */	
+	gtk_notebook_append_page_menu(GTK_NOTEBOOK(left_notebook),fileb,new_pixmap(105),gtk_label_new(_("Filebrowser")));
+	gtk_notebook_append_page_menu(GTK_NOTEBOOK(left_notebook),fref,new_pixmap(106),gtk_label_new(_("Function reference")));
+	gtk_notebook_append_page_menu(GTK_NOTEBOOK(left_notebook),bmarks,new_pixmap(104),gtk_label_new(_("Bookmarks")));
 	gtk_widget_show_all(left_notebook);
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(left_notebook),0);
 	return left_notebook;
@@ -239,9 +232,7 @@ void left_panel_rebuild(Tbfwin *bfwin) {
 		DEBUG_MSG("left_panel_rebuild, cleanup\n");
 		filebrowser_cleanup(bfwin);
 		fref_cleanup(bfwin);
-#ifdef BOOKMARKS
-      bmark_cleanup(bfwin);
-#endif /* BOOKMARKS */		
+		bmark_cleanup(bfwin);
 		DEBUG_MSG("left_panel_rebuild, re-init\n");
 		bfwin->leftpanel_notebook = left_panel_build(bfwin);
 		gtk_paned_add1(GTK_PANED(bfwin->hpane), bfwin->leftpanel_notebook);
@@ -265,9 +256,7 @@ void left_panel_show_hide_toggle(Tbfwin *bfwin,gboolean first_time, gboolean sho
 			gtk_widget_destroy(bfwin->hpane);
 			filebrowser_cleanup(bfwin);
 			fref_cleanup(bfwin);
-#ifdef BOOKMARKS
-         bmark_cleanup(bfwin); 
-#endif /* BOOKMARKS */			
+			bmark_cleanup(bfwin); 
 		}
 	}
 	if (show) {
@@ -497,28 +486,28 @@ static void quicklist_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
 	quicklist_dialog(bfwin,NULL);
 }
 static void link_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
-	link_dialog(bfwin,NULL);
+	linkdialog_dialog(bfwin,NULL);
 }
 static void formdialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
 	formdialog_dialog(bfwin,NULL);
 }
-static void buttondialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
-	buttondialog_dialog(bfwin,NULL);
+static void inputbuttondialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
+	inputdialog_dialog(bfwin, NULL, "submit");
 }
 static void textdialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
-	textdialog_dialog(bfwin,NULL);
+	inputdialog_dialog(bfwin, NULL, "text");
 }
 static void hiddendialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
-	hiddendialog_dialog(bfwin,NULL);
+	inputdialog_dialog(bfwin, NULL, "hidden");
 }
 static void textareadialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
 	textareadialog_dialog(bfwin,NULL);
 }
 static void radiodialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
-	radiodialog_dialog(bfwin,NULL);
+	inputdialog_dialog(bfwin, NULL, "radio");
 }
 static void checkdialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
-	checkdialog_dialog(bfwin,NULL);
+	inputdialog_dialog(bfwin, NULL, "checkbox");
 }
 static void selectdialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
 	selectdialog_dialog(bfwin,NULL);
@@ -529,6 +518,9 @@ static void optiondialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
 static void optgroupdialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
 	optgroupdialog_dialog(bfwin,NULL);
 }
+static void buttondialog_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
+	buttondialog_dialog(bfwin,NULL);
+}
 static void image_insert_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
 	image_insert_dialog(bfwin,NULL);
 }
@@ -619,15 +611,16 @@ static Ttoolbaritem tbi[] = {
 	{"noframes", noframes_clicked_lcb,  60, N_("Noframes")},
 	{"target", target_clicked_lcb,  61, N_("Target")},
 	{"form...",formdialog_clicked_lcb , 62, N_("Form...")},
-	{"inputbutton...", buttondialog_clicked_lcb, 63, N_("Input button...")},
-	{"text...",textdialog_clicked_lcb , 65, N_("Text...")},
-	{"hidden...", hiddendialog_clicked_lcb, 66, N_("Hidden...")},
+	{"inputbutton...", inputbuttondialog_clicked_lcb, 63, N_("Input Button...")},
+	{"text...",textdialog_clicked_lcb , 65, N_("Input Text...")},
+	{"hidden...", hiddendialog_clicked_lcb, 66, N_("Input Hidden...")},
 	{"textarea...",textareadialog_clicked_lcb , 67, N_("Textarea...")},
-	{"radiobutton...", radiodialog_clicked_lcb, 68, N_("Radio Button...")},
-	{"checkbox...", checkdialog_clicked_lcb, 69, N_("Check Box...")},
+	{"radiobutton...", radiodialog_clicked_lcb, 68, N_("Input Radio Button...")},
+	{"checkbox...", checkdialog_clicked_lcb, 69, N_("Input Check Box...")},
 	{"select...", selectdialog_clicked_lcb, 70, N_("Select...")},
 	{"option...",optiondialog_clicked_lcb , 71, N_("Option...")},
 	{"optiongroup...", optgroupdialog_clicked_lcb, 72, N_("Option group...")},
+	{"button...", buttondialog_clicked_lcb, 63, N_("Button...")},
 	{"quicklist...", quicklist_clicked_lcb, 73, N_("Quick List...")},
 	{"unorderedlist", unorderedlist_clicked_lcb,  74, N_("Unordered List")},
 	{"orderedlist", orderedlist_clicked_lcb,  75, N_("Ordered List")},
@@ -656,7 +649,7 @@ static Ttoolbaritem tbi[] = {
 
 static void html_toolbar_remove_from_quickbar_lcb(GtkMenuItem *menuitem, Ttoolbaritem *tbitem) {
 	GList *bfwlist;
-	main_v->props.quickbar_items = remove_from_stringlist(main_v->props.quickbar_items, tbitem->ident);
+	main_v->globses.quickbar_items = remove_from_stringlist(main_v->globses.quickbar_items, tbitem->ident);
 	bfwlist = g_list_first(main_v->bfwinlist);
 	while (bfwlist) {
 		Tquickbaritem *qbi=NULL;
@@ -696,7 +689,7 @@ static gboolean html_toolbar_quickbar_item_button_press_lcb(GtkWidget *widget,Gd
 static void html_toolbar_add_to_quickbar_lcb(GtkMenuItem *menuitem, Ttoolbaritem *tbitem) {
 	GList *tmplist = g_list_first(main_v->bfwinlist);
 	DEBUG_MSG("adding tbitem %p to quickbars\n", tbitem);
-	main_v->props.quickbar_items = add_to_stringlist(main_v->props.quickbar_items, tbitem->ident);
+	main_v->globses.quickbar_items = add_to_stringlist(main_v->globses.quickbar_items, tbitem->ident);
 	while (tmplist) {
 		Tquickbaritem *qbi;
 		Tbfwin *bfwin = BFWIN(tmplist->data);
@@ -735,7 +728,7 @@ static void html_toolbar_add_items(Tbfwin *bfwin, GtkWidget *html_toolbar, Ttool
 			gtk_toolbar_append_space(GTK_TOOLBAR(html_toolbar));
 		} else {
 			item = gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _(tbi[i].tooltiptext),
-						"", new_pixmap(tbi[i].pixmaptype), G_CALLBACK(tbi[i].func), bfwin);
+						NULL, new_pixmap(tbi[i].pixmaptype), G_CALLBACK(tbi[i].func), bfwin);
 			g_signal_connect(item, "button-press-event", G_CALLBACK(html_toolbar_item_button_press_lcb), &tbi[i]);
 			DEBUG_MSG("adding tbitem %p to html_toolbar\n", &tbi[i]);
 		}
@@ -788,11 +781,12 @@ void make_html_toolbar(Tbfwin *bfwin) {
 	gtk_container_add(GTK_CONTAINER(bfwin->html_toolbar_hb), html_notebook);
 
 	bfwin->toolbar_quickbar = gtk_toolbar_new();
+	gtk_toolbar_set_style(GTK_TOOLBAR(bfwin->toolbar_quickbar), GTK_TOOLBAR_ICONS);
 	DEBUG_MSG("make_html_toolbar, creating quickbar\n");
 	{
 		GList *tmplist;
 		gint i, numitems=(sizeof(tbi)/sizeof(Ttoolbaritem));
-		tmplist = g_list_first(main_v->props.quickbar_items);
+		tmplist = g_list_first(main_v->globses.quickbar_items);
 		while (tmplist) {
 			gchar *tmpstr = tmplist->data;
 			DEBUG_MSG("make_html_toolbar, searching for %s\n", tmpstr);
@@ -813,35 +807,42 @@ void make_html_toolbar(Tbfwin *bfwin) {
 	gtk_notebook_append_page(GTK_NOTEBOOK(html_notebook), bfwin->toolbar_quickbar, gtk_label_new(_(" Quick bar ")));
 
 	html_toolbar = gtk_toolbar_new();
+	gtk_toolbar_set_style(GTK_TOOLBAR(html_toolbar), GTK_TOOLBAR_ICONS);
 	html_toolbar_add_items(bfwin,html_toolbar, tbi, 0, 14);
 	html_toolbar_add_items_to_submenu(bfwin,html_toolbar, tbi, 26, 31, _("Heading"), 91);
 	html_toolbar_add_items(bfwin,html_toolbar, tbi, 75, 77);
 	gtk_notebook_append_page(GTK_NOTEBOOK(html_notebook), html_toolbar, gtk_label_new(_(" Standard bar ")));
 
 	html_toolbar = gtk_toolbar_new();
+	gtk_toolbar_set_style(GTK_TOOLBAR(html_toolbar), GTK_TOOLBAR_ICONS);
 	html_toolbar_add_items(bfwin,html_toolbar, tbi, 15, 25);
 	html_toolbar_add_items_to_submenu(bfwin,html_toolbar, tbi, 78, 85, _("Context formatting"), 103);
 	html_toolbar_add_items(bfwin,html_toolbar, tbi, 25, 31);
 	gtk_notebook_append_page(GTK_NOTEBOOK(html_notebook), html_toolbar, gtk_label_new(_(" Fonts ")));
 
 	html_toolbar = gtk_toolbar_new();
+	gtk_toolbar_set_style(GTK_TOOLBAR(html_toolbar), GTK_TOOLBAR_ICONS);
 	html_toolbar_add_items(bfwin,html_toolbar, tbi, 32, 43);
 	gtk_notebook_append_page(GTK_NOTEBOOK(html_notebook), html_toolbar, gtk_label_new(_(" Tables ")));
 
 	html_toolbar = gtk_toolbar_new();
+	gtk_toolbar_set_style(GTK_TOOLBAR(html_toolbar), GTK_TOOLBAR_ICONS);
 	html_toolbar_add_items(bfwin,html_toolbar, tbi, 44, 52);
 	gtk_notebook_append_page(GTK_NOTEBOOK(html_notebook), html_toolbar, gtk_label_new(_(" Frames ")));
 
 	html_toolbar = gtk_toolbar_new();
-	html_toolbar_add_items(bfwin,html_toolbar, tbi, 53, 62);
+	gtk_toolbar_set_style(GTK_TOOLBAR(html_toolbar), GTK_TOOLBAR_ICONS);
+	html_toolbar_add_items(bfwin,html_toolbar, tbi, 53, 63);
 	gtk_notebook_append_page(GTK_NOTEBOOK(html_notebook), html_toolbar, gtk_label_new(_(" Forms ")));
 
 	html_toolbar = gtk_toolbar_new();
-	html_toolbar_add_items(bfwin,html_toolbar, tbi, 63, 69);
+	gtk_toolbar_set_style(GTK_TOOLBAR(html_toolbar), GTK_TOOLBAR_ICONS);
+	html_toolbar_add_items(bfwin,html_toolbar, tbi, 64, 70);
 	gtk_notebook_append_page(GTK_NOTEBOOK(html_notebook), html_toolbar, gtk_label_new(_(" List ")));
 
 	html_toolbar = gtk_toolbar_new();
-	html_toolbar_add_items(bfwin,html_toolbar, tbi, 70, 72);
+	gtk_toolbar_set_style(GTK_TOOLBAR(html_toolbar), GTK_TOOLBAR_ICONS);
+	html_toolbar_add_items(bfwin,html_toolbar, tbi, 71, 73);
 	gtk_notebook_append_page(GTK_NOTEBOOK(html_notebook), html_toolbar, gtk_label_new(_(" CSS ")));
 
 	gtk_widget_show_all(html_notebook);
@@ -930,12 +931,15 @@ void gui_set_undo_redo_widgets(Tbfwin *bfwin, gboolean undo, gboolean redo) {
 	gtk_widget_set_sensitive(gtk_item_factory_get_widget(gtk_item_factory_from_widget(bfwin->menubar), N_("/Edit/Redo All")), redo);
 }
 
-void gui_set_widgets(Tbfwin *bfwin, gboolean undo, gboolean redo, gboolean wrap, gboolean highlight, Tfiletype *hl, gchar *encoding, gboolean linenumbers) {
-	gui_set_undo_redo_widgets(bfwin, undo, redo);
-	setup_toggle_item(gtk_item_factory_from_widget(bfwin->menubar),N_("/Document/Highlight Syntax"), highlight);
-	setup_toggle_item(gtk_item_factory_from_widget(bfwin->menubar),N_("/Document/Wrap"), wrap);
-	setup_toggle_item(gtk_item_factory_from_widget(bfwin->menubar),N_("/Document/Line Numbers"), linenumbers);
-	menu_current_document_set_toggle_wo_activate(bfwin,hl, encoding);
+void gui_set_document_widgets(Tdocument *doc) {
+	GtkItemFactory *tmp1 = gtk_item_factory_from_widget(BFWIN(doc->bfwin)->menubar);
+	setup_toggle_item(tmp1,N_("/Document/Highlight Syntax"), (doc->highlightstate && doc->hl->highlightlist != NULL));
+	gtk_widget_set_sensitive(gtk_item_factory_get_widget(tmp1,N_("/Document/Highlight Syntax")), (doc->hl->highlightlist != NULL));
+	gui_set_undo_redo_widgets(doc->bfwin, doc_has_undo_list(doc), doc_has_redo_list(doc));
+	setup_toggle_item(gtk_item_factory_from_widget(BFWIN(doc->bfwin)->menubar),N_("/Document/Wrap"), doc->wrapstate);
+	setup_toggle_item(gtk_item_factory_from_widget(BFWIN(doc->bfwin)->menubar),N_("/Document/Line Numbers"), doc->linenumberstate);
+	setup_toggle_item(gtk_item_factory_from_widget(BFWIN(doc->bfwin)->menubar),N_("/Document/Auto Close HTML tags"), doc->autoclosingtag);
+	menu_current_document_set_toggle_wo_activate(BFWIN(doc->bfwin),doc->hl, doc->encoding);
 }
 
 void gui_notebook_bind_signals(Tbfwin *bfwin) {
@@ -953,19 +957,19 @@ static gboolean gui_main_window_configure_event_lcb(GtkWidget *widget,GdkEvent *
 	if (main_v->props.restore_dimensions) {
 		if (revent->type == GDK_CONFIGURE) {
 			GdkEventConfigure *event = (GdkEventConfigure *)revent;
-			if (main_v->props.main_window_w > 0 ) {
-				main_v->props.main_window_w = event->width;
-				main_v->props.main_window_h = event->height;
-				DEBUG_MSG("gui_main_window_configure_event_lcb, width=%d, height=%d\n",event->width,event->height);
+			if (main_v->globses.main_window_w > 0 ) {
+				main_v->globses.main_window_w = event->width;
+				main_v->globses.main_window_h = event->height;
+				DEBUG_MSG("gui_main_window_configure_event_lcb, width=%d, height=%d\n",main_v->globses.main_window_w,main_v->globses.main_window_h);
 			}
 		} else if (revent->type == GDK_WINDOW_STATE) {
 			GdkEventWindowState *event = (GdkEventWindowState *)revent;
-			if (event->new_window_state == GDK_WINDOW_STATE_MAXIMIZED && main_v->props.main_window_w > 0) {
-				main_v->props.main_window_w = -1 * main_v->props.main_window_w; /* negative means it is maximized !! */
-				DEBUG_MSG("gui_main_window_configure_event_lcb, maximized!! width=%d\n",main_v->props.main_window_w);
-			} else if (event->new_window_state != GDK_WINDOW_STATE_MAXIMIZED && main_v->props.main_window_w < 0) {
-				main_v->props.main_window_w = -1 * main_v->props.main_window_w; /* make it positive again */
-				DEBUG_MSG("gui_main_window_configure_event_lcb, NOT-maximized, width=%d\n",main_v->props.main_window_w);
+			if (event->new_window_state == GDK_WINDOW_STATE_MAXIMIZED && main_v->globses.main_window_w > 0) {
+				main_v->globses.main_window_w = -1 * main_v->globses.main_window_w; /* negative means it is maximized !! */
+				DEBUG_MSG("gui_main_window_configure_event_lcb, maximized!! width=%d\n",main_v->globses.main_window_w);
+			} else if (event->new_window_state != GDK_WINDOW_STATE_MAXIMIZED && main_v->globses.main_window_w < 0) {
+				main_v->globses.main_window_w = -1 * main_v->globses.main_window_w; /* make it positive again */
+				DEBUG_MSG("gui_main_window_configure_event_lcb, NOT-maximized, width=%d\n",main_v->globses.main_window_w);
 			}
 		}
 	}
@@ -1001,7 +1005,7 @@ static void main_win_on_drag_data_lcb(GtkWidget * widget, GdkDragContext * conte
 
 	/* construct both filename and url from the given data */
 	if (info == TARGET_STRING) {
-		filename = g_strndup(data->data, data->length);
+		filename = g_strndup((gchar *)data->data, data->length);
 		filename = trunc_on_char(trunc_on_char(filename, '\n'), '\r');
 		url = g_strconcat("file:", filename, NULL);
 		url_is_local = 1;
@@ -1010,7 +1014,7 @@ static void main_win_on_drag_data_lcb(GtkWidget * widget, GdkDragContext * conte
 		gchar *tmp2;
 		gint len;
 
-		url = g_strndup(data->data, data->length);
+		url = g_strndup((gchar *)data->data, data->length);
 		url = trunc_on_char(trunc_on_char(url, '\n'), '\r');
 		if (strncmp(url, "file://", 7) == 0) {
 			filename = g_strdup(url+7);
@@ -1036,8 +1040,23 @@ static void main_win_on_drag_data_lcb(GtkWidget * widget, GdkDragContext * conte
 }
 
 void gui_bfwin_cleanup(Tbfwin *bfwin) {
+	GList *tmplist;
 	/* call all cleanup functions here */
 	/*remove_window_entry_from_all_windows(bfwin);*/
+	
+	/* all documents have to be freed for this window */
+	tmplist = g_list_first(bfwin->documentlist);
+	DEBUG_MSG("gui_bfwin_cleanup, have %d documents in window %p\n",g_list_length(bfwin->documentlist),bfwin);
+	while (tmplist) {
+		DEBUG_MSG("gui_bfwin_cleanup closing doc=%p\n",tmplist->data);
+		doc_destroy(DOCUMENT(tmplist->data), TRUE);
+		/* no this is not an indefinite loop, because the documents remove themselves
+		from the documentlist, we remove the top document untill there are no documents
+		left */
+		tmplist = g_list_first(bfwin->documentlist);
+	}
+	
+	bmark_cleanup(bfwin);
 }
 
 void main_window_destroy_lcb(GtkWidget *widget,Tbfwin *bfwin) {
@@ -1049,7 +1068,6 @@ void main_window_destroy_lcb(GtkWidget *widget,Tbfwin *bfwin) {
 	gui_bfwin_cleanup(bfwin);
 	DEBUG_MSG("main_window_destroy_lcb, will destroy the window now\n");
 	gtk_widget_destroy(bfwin->main_window);
-	free_session(bfwin->session);
 	g_free(bfwin);
 	DEBUG_MSG("main_window_destroy_lcb, bfwin is free'ed\n");
 	if (NULL == main_v->bfwinlist) {
@@ -1075,7 +1093,7 @@ gboolean main_window_delete_event_lcb(GtkWidget *widget,GdkEvent *event,Tbfwin *
 			DEBUG_MSG("main_window_delete_event_lcb, continue clicked, returning FALSE\n");
 			return FALSE;
 		}
-	} else {	
+	} else {
 		if (bfwin->documentlist && test_docs_modified(bfwin->documentlist)) {
 			DEBUG_MSG("main_window_delete_event_lcb, we have changed documents!\n");
 			file_close_all_cb(NULL, bfwin);
@@ -1084,6 +1102,9 @@ gboolean main_window_delete_event_lcb(GtkWidget *widget,GdkEvent *event,Tbfwin *
 				/* if there are still documents modified we should cancel the closing */
 				return TRUE;
 			}
+		} else {
+			/* no changed documents, but there might be changed bookmarks */
+			bmark_store_all(bfwin);
 		}
 	}
 	return FALSE;
@@ -1091,12 +1112,13 @@ gboolean main_window_delete_event_lcb(GtkWidget *widget,GdkEvent *event,Tbfwin *
 
 void gui_create_main(Tbfwin *bfwin, GList *filenames) {
 	GtkWidget *vbox;
+	DEBUG_MSG("gui_create_main, bfwin=%p, bfwin->bookmarkstore=%p\n",bfwin,bfwin->bookmarkstore);
 	bfwin->main_window = window_full2(_("New Bluefish Window"), GTK_WIN_POS_CENTER, 0, G_CALLBACK(main_window_destroy_lcb), bfwin, FALSE, NULL);
 	gtk_window_set_role(GTK_WINDOW(bfwin->main_window), "bluefish");
-	if (main_v->props.main_window_w > 0) {
-		gtk_window_set_default_size(GTK_WINDOW(bfwin->main_window), main_v->props.main_window_w, main_v->props.main_window_h);
+	if (main_v->globses.main_window_w > 0) {
+		gtk_window_set_default_size(GTK_WINDOW(bfwin->main_window), main_v->globses.main_window_w, main_v->globses.main_window_h);
 	} else {
-		gtk_window_set_default_size(GTK_WINDOW(bfwin->main_window), main_v->props.main_window_w * -1, main_v->props.main_window_h);
+		gtk_window_set_default_size(GTK_WINDOW(bfwin->main_window), main_v->globses.main_window_w * -1, main_v->globses.main_window_h);
 		gtk_window_maximize(GTK_WINDOW(bfwin->main_window));
 	}
 	g_signal_connect(G_OBJECT(bfwin->main_window), "delete_event", G_CALLBACK(main_window_delete_event_lcb), bfwin);
@@ -1405,7 +1427,7 @@ GtkWidget *start_splash_screen() {
 	gtk_window_set_decorated(GTK_WINDOW(splashscreen.window), FALSE);
 	gtk_window_set_role(GTK_WINDOW(splashscreen.window), "splash");
 	gtk_window_set_resizable(GTK_WINDOW(splashscreen.window),FALSE);
-	gtk_widget_set_usize(splashscreen.window, 340, 400);
+	gtk_widget_set_size_request(splashscreen.window, 340, 400);
 	color.red = 65535;
 	color.blue = 65535;
 	color.green = 65535;
@@ -1439,11 +1461,6 @@ GtkWidget *start_splash_screen() {
 }
 #endif /* #ifndef NOSPLASH */
 
-
-void gui_toggle_autoindent_cb(gpointer callback_data,guint action,GtkWidget *widget) {
-	main_v->props.autoindent = 1 - main_v->props.autoindent;
-}
-
 void gui_set_html_toolbar_visible(Tbfwin *bfwin, gboolean visible, gboolean sync_menu) {
 	if (sync_menu) setup_toggle_item(gtk_item_factory_from_widget(bfwin->menubar), N_("/View/View HTML Toolbar"), visible);
 	if (gtk_container_children(GTK_CONTAINER(bfwin->html_toolbar_hb)) == NULL) {
@@ -1495,11 +1512,16 @@ void gui_toggle_hidewidget_cb(Tbfwin *bfwin,guint action,GtkWidget *widget) {
 
 Tbfwin *gui_new_window(GList *filenames, Tproject *project) {
 	Tbfwin *bfwin = g_new0(Tbfwin,1);
+	bfwin->bmark_files = NULL; /* Oskar */
 	if (project) {
 		bfwin->project = project;
 		bfwin->session = project->session;
+		bfwin->bookmarkstore = project->bookmarkstore;
+		DEBUG_MSG("gui_new_window, bfwin=%p, bfwin->bookmarkstore=%p (from project %p)\n",bfwin,bfwin->bookmarkstore,project);
 	} else {
-		bfwin->session = g_new0(Tsessionvars,1);
+		bfwin->session = main_v->session;
+		bfwin->bookmarkstore = main_v->bookmarkstore;
+		DEBUG_MSG("gui_new_window, bfwin=%p, bfwin->bookmarkstore=%p (from main_v)\n",bfwin,bfwin->bookmarkstore);
 	}
 	gui_create_main(bfwin,filenames);
 	/* never comment this out again Jim! */
