@@ -476,11 +476,12 @@ void filetype_highlighting_rebuild() {
 		Tfiletype *filetype;
 		strarr = (gchar **) tmplist->data;
 		arrcount = count_array(strarr);
-		if (arrcount == 6) {
+		if (arrcount == 7) {
 			filetype = g_new(Tfiletype, 1);
 			filetype->editable = (strarr[4][0] != '0');
 			filetype->content_regex = g_strdup(strarr[5]);
 			filetype->type = g_strdup(strarr[0]);
+			filetype->autoclosingtag = atoi(strarr[6]);
 			DEBUG_MSG("extensions for %s loaded from %s\n", strarr[0], strarr[1]);
 			filetype->extensions = g_strsplit(strarr[1], ":", 127);
 			filetype->update_chars = g_strdup(strarr[2]);
@@ -1102,9 +1103,9 @@ void doc_highlight_line(Tdocument * doc)
 					DEBUG_MSG("doc_highlight_line, tag %p goes with ", testpat->tag);
 					print_meta_for_pattern(testpat);
 				} else {
-					DEBUG_MSG("doc_highlight_line, tag doesn't have parent?? ");
+					DEBUG_MSG("doc_highlight_line, tag %p doesn't have pattern??\n",slist->data);
 					print_meta_for_tag(GTK_TEXT_TAG(slist->data));
-					exit(9);
+					/*exit(9);*/
 				}
 				test = gtk_text_buffer_get_text(doc->buffer, &itstart, &itend,FALSE);
 				DEBUG_MSG("doc_highlight_line, current string='%s'\n", test);
