@@ -22,7 +22,7 @@
  */
 /* 
  * Changes by Antti-Juhani Kaijanaho <gaia@iki.fi> on 1999-10-20
- * $Id: html.c,v 1.34 2003/10/24 08:36:04 oli4 Exp $
+ * $Id: html.c,v 1.42 2004/03/07 11:33:42 oli4 Exp $
  */
 /*#define DEBUG*/
 
@@ -92,7 +92,7 @@ void general_html_menu_cb(Tbfwin* bfwin,guint callback_action, GtkWidget *widget
 		doc_insert_two_strings(bfwin->current_document, cap("<STRIKE>"), cap("</STRIKE>"));
 		break;
 	case 5:
-		doc_insert_two_strings(bfwin->current_document, cap("<P>"), main_v->props.full_p == 1 ? cap("</P>") : NULL);
+		doc_insert_two_strings(bfwin->current_document, cap("<P>"), cap("</P>"));
 		break;
 	case 6:
 		doc_insert_two_strings(bfwin->current_document, main_v->props.xhtml == 1 ? cap("<br />") : cap("<br>"), NULL);
@@ -184,16 +184,16 @@ void general_html_menu_cb(Tbfwin* bfwin,guint callback_action, GtkWidget *widget
 		doc_insert_two_strings(bfwin->current_document, cap("<OL>"), cap("</OL>"));
 		break;
 	case 35:
-		doc_insert_two_strings(bfwin->current_document, cap("<LI>"), main_v->props.full_li == 1 ? cap("</LI>") : NULL);
+		doc_insert_two_strings(bfwin->current_document, cap("<LI>"), cap("</LI>"));
 		break;
 	case 36:
-		doc_insert_two_strings(bfwin->current_document, main_v->props.full_li == 1 ? cap("<DL>\n<DT></DT>\n\t<DD></DD>\n</DL>") : cap("<DL>\n<DT>\n\t<DD>\n</DL>"), "\n");
+		doc_insert_two_strings(bfwin->current_document, cap("<DL>\n<DT></DT>\n\t<DD></DD>\n</DL>"), "\n");
 		break;
 	case 37:
-		doc_insert_two_strings(bfwin->current_document, cap("<DT>"), main_v->props.full_li == 1 ? cap("</DT>") : NULL);
+		doc_insert_two_strings(bfwin->current_document, cap("<DT>"), cap("</DT>"));
 		break;
 	case 38:
-		doc_insert_two_strings(bfwin->current_document, cap("<DD>"), main_v->props.full_li == 1 ? cap("</DD>") : NULL);
+		doc_insert_two_strings(bfwin->current_document, cap("<DD>"), cap("</DD>"));
 		break;
 	case 39:
 		doc_insert_two_strings(bfwin->current_document, cap("<MENU>"), cap("</MENU>"));
@@ -506,7 +506,6 @@ static void quickanchorok_lcb(GtkWidget * widget, Thtml_diag * dg)
 	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(dg->combo[2])->entry), cap("HREF"), thestring, NULL);
 	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(dg->combo[1])->entry), cap("TARGET"), thestring, NULL);
 	thestring = insert_string_if_entry(GTK_WIDGET(dg->entry[2]), cap("NAME"), thestring, NULL);
-	thestring = insert_string_if_entry(GTK_WIDGET(dg->entry[3]), cap("ID"), thestring, NULL);
 	thestring = insert_string_if_entry(GTK_WIDGET(dg->entry[4]), NULL, thestring, NULL);
 	thestring = insert_string_if_entry(GTK_WIDGET(dg->entry[5]), cap("ONCLICK"), thestring, NULL);
 	thestring = insert_string_if_entry(GTK_WIDGET(dg->entry[6]), cap("ONDBLCLICK"), thestring, NULL);
@@ -518,15 +517,16 @@ static void quickanchorok_lcb(GtkWidget * widget, Thtml_diag * dg)
 	thestring = insert_string_if_entry(GTK_WIDGET(dg->entry[12]), cap("ONKEYDOWN"), thestring, NULL);
 	thestring = insert_string_if_entry(GTK_WIDGET(dg->entry[13]), cap("ONKEYPRESS"), thestring, NULL);
 	thestring = insert_string_if_entry(GTK_WIDGET(dg->entry[14]), cap("ONKEYUP"), thestring, NULL);
-	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(dg->combo[3])->entry), cap("CLASS"), thestring, NULL);
-	thestring = insert_string_if_entry(GTK_WIDGET(dg->entry[16]), cap("STYLE"), thestring, NULL);
+	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(dg->attrwidget[0])->entry), cap("CLASS"), thestring, NULL);
+	thestring = insert_string_if_entry(GTK_WIDGET(dg->attrwidget[1]), cap("ID"), thestring, NULL);
+	thestring = insert_string_if_entry(GTK_WIDGET(dg->attrwidget[2]), cap("STYLE"), thestring, NULL);
 	thestring = insert_string_if_entry(GTK_WIDGET(dg->entry[17]), cap("LANG"), thestring, NULL);
 	finalstring = g_strdup_printf("%s>", thestring);
 	g_free(thestring);
 
 	bfwin->session->urllist = add_entry_to_stringlist(bfwin->session->urllist, GTK_WIDGET(GTK_COMBO(dg->combo[2])->entry));
 	bfwin->session->targetlist = add_entry_to_stringlist(bfwin->session->targetlist, GTK_WIDGET(GTK_COMBO(dg->combo[1])->entry));
-	bfwin->session->classlist = add_entry_to_stringlist(bfwin->session->classlist, GTK_WIDGET(GTK_COMBO(dg->combo[3])->entry));
+	bfwin->session->classlist = add_entry_to_stringlist(bfwin->session->classlist, GTK_WIDGET(GTK_COMBO(dg->attrwidget[0])->entry));
 
 	if (dg->range.end == -1) {
 		doc_insert_two_strings(dg->doc, finalstring, cap("</A>"));
@@ -538,12 +538,12 @@ static void quickanchorok_lcb(GtkWidget * widget, Thtml_diag * dg)
 }
 
 void quickanchor_dialog(Tbfwin *bfwin, Ttagpopup *data) {
-	static gchar *aitems[] = { "href", "target", "name", "id", "onclick", "ondblclick", "onmouseover", "onmousedown", "onmousemove", "onmouseout", "onmouseup", "onkeydown", "onkeypress", "onkeyup", "class", "style", "lang", NULL };
+	static gchar *aitems[] = { "href", "target", "name", "onkeyup", "onclick", "ondblclick", "onmouseover", "onmousedown", "onmousemove", "onmouseout", "onmouseup", "onkeydown", "onkeypress", "class", "id", "style", "lang", NULL };
 	gchar *custom = NULL;
 	gchar *avalues[18];
 	Thtml_diag *dg;
 
-	GtkWidget *noteb, *but, *dgtable, *file_but, *frame;
+	GtkWidget *noteb, *dgtable, *file_but;
 	DEBUG_MSG("quickanchor_dialog, bfwin=%p, data=%p\n",bfwin,data);
 	dg = html_diag_new(bfwin,_("Quick Anchor"));
 	fill_dialogvalues(aitems, avalues, &custom, (Ttagpopup *) data, dg);
@@ -551,11 +551,7 @@ void quickanchor_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	noteb = gtk_notebook_new();
 	gtk_box_pack_start(GTK_BOX(dg->vbox), noteb, FALSE, FALSE, 0);
 
-	frame = bf_generic_frame_new(NULL, GTK_SHADOW_NONE, 12);
-	gtk_notebook_append_page(GTK_NOTEBOOK(noteb), frame, gtk_label_new(_("Options")));
-	dgtable = gtk_table_new(8, 3, FALSE);
-	gtk_table_set_col_spacings(GTK_TABLE(dgtable), 12);
-	gtk_container_add(GTK_CONTAINER(frame), dgtable);
+	dgtable = generic_table_inside_notebookframe(noteb, _("Attributes"), 8, 3);
 
 	{
 		GList *rel_link_list=NULL, *tmplist;
@@ -580,20 +576,7 @@ void quickanchor_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	bf_mnemonic_label_tad_with_alignment(_("_Name:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 3, 2, 3);
 
-	dg->entry[3] = entry_with_text(avalues[3], 256);
-	bf_mnemonic_label_tad_with_alignment(_("_ID:"), dg->entry[3], 0, 0.5, dgtable, 0, 1, 3, 4);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[3], 1, 3, 3, 4);
-
-	dg->combo[3] = combo_with_popdown(avalues[14], bfwin->session->classlist, 1);
-	bf_mnemonic_label_tad_with_alignment(_("Cl_ass:"), dg->combo[3], 0, 0.5, dgtable, 0, 1, 4, 5);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[3], 1, 3, 4, 5);
-
-	dg->entry[16] = entry_with_text(avalues[15], 256);
-	bf_mnemonic_label_tad_with_alignment(_("St_yle:"), dg->entry[16], 0, 0.5, dgtable, 0, 1, 5, 6);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[16], 1, 2, 5, 6);
-
-	but = style_but_new(dg->entry[16], dg->dialog);
-	gtk_table_attach(GTK_TABLE(dgtable), but, 2, 3, 5, 6, GTK_SHRINK, GTK_SHRINK, 0, 0);
+	generic_class_id_style_section(dg, 0, dgtable, 3, avalues, 13);
 
 	dg->entry[17] = entry_with_text(avalues[16], 256);
 	bf_mnemonic_label_tad_with_alignment(_("_Language:"), dg->entry[17], 0, 0.5, dgtable, 0, 1, 6, 7);
@@ -603,12 +586,7 @@ void quickanchor_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[4], 0, 0.5, dgtable, 0, 1, 7, 8);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[4], 1, 3, 7, 8);
 
-	frame = bf_generic_frame_new(NULL, GTK_SHADOW_NONE, 12);
-	gtk_notebook_append_page(GTK_NOTEBOOK(noteb), frame, gtk_label_new(_("Events")));
-	dgtable = gtk_table_new(10, 2, FALSE);
-	gtk_table_set_row_spacings(GTK_TABLE(dgtable), 6);
-	gtk_table_set_col_spacings(GTK_TABLE(dgtable), 12);
-	gtk_container_add(GTK_CONTAINER(frame), dgtable);
+	dgtable = generic_table_inside_notebookframe(noteb, _("Events"), 10, 2);
 
 	dg->entry[5] = entry_with_text(avalues[4], 256);
 	bf_mnemonic_label_tad_with_alignment(_("OnClic_k:"), dg->entry[5], 0, 0.5, dgtable, 0, 1, 0, 1);
@@ -646,7 +624,7 @@ void quickanchor_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	bf_mnemonic_label_tad_with_alignment(_("OnKey_Press:"), dg->entry[13], 0, 0.5, dgtable, 0, 1, 8, 9);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[13], 1, 2, 8, 9);
 
-	dg->entry[14] = entry_with_text(avalues[13], 256);
+	dg->entry[14] = entry_with_text(avalues[3], 256);
 	bf_mnemonic_label_tad_with_alignment(_("OnKe_yUp:"), dg->entry[14], 0, 0.5, dgtable, 0, 1, 9, 10);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[14], 1, 2, 9, 10);
 
@@ -888,15 +866,14 @@ void h6_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 
 
 
-static void quickruleok_lcb(GtkWidget * widget, Thtml_diag * dg)
-{
+static void quickruleok_lcb(GtkWidget * widget, Thtml_diag * dg) {
 	gchar *thestring, *finalstring;
 
 	thestring = g_strdup(cap("<HR"));
 	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(dg->combo[1])->entry), cap("ALIGN"), thestring, NULL);
-	thestring = insert_integer_if_spin(dg->spin[1], cap("SIZE"), thestring, NULL);
-	thestring = insert_integer_if_spin(dg->spin[2], cap("WIDTH"), thestring, dg->check[1]);
-	thestring = insert_attr_if_checkbox(dg->check[2], cap("NOSHADE"), thestring);
+	thestring = insert_integer_if_spin(dg->spin[1], cap("SIZE"), thestring, FALSE, 1);
+	thestring = insert_integer_if_spin(dg->spin[2], cap("WIDTH"), thestring, GTK_TOGGLE_BUTTON(dg->check[1])->active,GTK_TOGGLE_BUTTON(dg->check[1])->active ? 100 : 0);
+	thestring = insert_attr_if_checkbox(dg->check[2], main_v->props.xhtml == 1 ? cap("NOSHADE=\"noshade\"") : cap("NOSHADE"), thestring);
 	thestring = insert_string_if_entry(dg->entry[1], NULL, thestring, NULL);
 	finalstring = g_strdup_printf(main_v->props.xhtml == 1 ? "%s />" : "%s>", thestring);
 	g_free(thestring);
@@ -1239,7 +1216,7 @@ void body_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 									, "style", "class", "id", "language", "onload", "onunload", NULL };
 
 	GtkWidget *color_but, *file_but, *dgtable[3], *stylebut, *noteb, *hbox, *vbox2, *label, *frame;
-	gchar *bodyvalues[11];
+	gchar *bodyvalues[13];
 	gchar *custom = NULL;
 	Thtml_diag *dg;
 
@@ -1647,7 +1624,7 @@ static void quicklistok_lcb(GtkWidget * widget, Thtml_diag *dg)
 		/* TODO: use bf_str_repeat() function !!!!!!! */
 		/**********************************************/
 		for (i = 0; i < temp; i++) {
-			strcat(finalstring,  main_v->props.full_li == 1 ? cap("\n\t<LI></LI>") : cap("\n\t<LI>"));
+			strcat(finalstring,  cap("\n\t<LI></LI>"));
 		}
 		strcat(finalstring, "\n");
 
@@ -1940,31 +1917,16 @@ void embed_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	html_diag_finish(dg, G_CALLBACK(embedok_lcb));	
 }
 
-static void script_linkok_lcb(gint type, GtkWidget * widget,Thtml_diag *dg ) {
+static void scriptok_lcb(GtkWidget * widget,Thtml_diag *dg ) {
 	gchar *thestring, *finalstring, *endstring;
 
-	if (type == 0) {
-		thestring = g_strdup(cap("<SCRIPT"));
-		thestring = insert_string_if_entry(dg->entry[0], cap("SRC"), thestring, NULL);
-		thestring = insert_string_if_entry(GTK_COMBO(dg->combo[0])->entry, cap("LANGUAGE"), thestring, NULL);
-	} else {
-		thestring = g_strdup(cap("<LINK"));
-		thestring = insert_string_if_entry(dg->entry[0], cap("HREF"), thestring, NULL);
-		thestring = insert_string_if_entry(GTK_COMBO(dg->combo[0])->entry, cap("REL"), thestring, NULL);
-	}
+	thestring = g_strdup(cap("<SCRIPT"));
+	thestring = insert_string_if_entry(dg->entry[0], cap("SRC"), thestring, NULL);
+	thestring = insert_string_if_entry(GTK_COMBO(dg->combo[0])->entry, cap("LANGUAGE"), thestring, NULL);
 	thestring = insert_string_if_entry(GTK_COMBO(dg->combo[1])->entry, cap("TYPE"), thestring, NULL);
 	thestring = insert_string_if_entry(dg->entry[1], NULL, thestring, NULL);
-	if (main_v->props.xhtml == 1 && type == 1) {
-		finalstring = g_strconcat(thestring, " />", NULL);
-		endstring = NULL;
-	} else {
-		finalstring = g_strconcat(thestring, ">", NULL);
-		if (type == 0) {
-			endstring = cap("</SCRIPT>");
-		} else {
-			endstring = NULL;
-		}
-	}
+	finalstring = g_strconcat(thestring, ">", NULL);
+	endstring = cap("</SCRIPT>");
 	g_free(thestring);
 
 	if (dg->range.end == -1) {
@@ -1976,31 +1938,17 @@ static void script_linkok_lcb(gint type, GtkWidget * widget,Thtml_diag *dg ) {
 	html_diag_destroy_cb(NULL, dg);
 }
 
-static void linkok_lcb(GtkWidget * widget,Thtml_diag *dg ) {
-	script_linkok_lcb(1, widget, dg);
-}
-
-static void scriptok_lcb(GtkWidget * widget,Thtml_diag *dg ) {
-	script_linkok_lcb(0, widget, dg);
-}
-
-static void script_link_cb(gint type, Tbfwin *bfwin, Ttagpopup *data) {
+void script_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	GtkWidget *file_but;
 	GList *tmplist, *tmplist2;
 	GtkWidget *dgtable, *label;
 	Thtml_diag *dg;
 	static gchar *scriptitems[] =	{ "src", "language", "type", NULL };
-	static gchar *linkitems[] =	{ "href", "rel", "type", NULL };
 	gchar *tagvalues[4];
 	gchar *custom = NULL;
 
-	if (type == 0) {
-		dg = html_diag_new(bfwin,_("Script"));
-		fill_dialogvalues(scriptitems, tagvalues, &custom, (Ttagpopup *) data, dg);
-	} else {
-		dg = html_diag_new(bfwin,_("Link"));
-		fill_dialogvalues(linkitems, tagvalues, &custom, (Ttagpopup *) data, dg);
-	}
+	dg = html_diag_new(bfwin,_("Script"));
+	fill_dialogvalues(scriptitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 4, 12);
 	dg->entry[0] = entry_with_text(tagvalues[0], 1024);
@@ -2009,7 +1957,7 @@ static void script_link_cb(gint type, Tbfwin *bfwin, Ttagpopup *data) {
 	bf_mnemonic_label_tad_with_alignment(_("_Source:"), dg->entry[0], 0, 0.5, dgtable, 0, 2, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[0], 2, 10, 0, 1);
 
-	if (type == 0) {
+
 		tmplist = g_list_append(NULL, "javascript");
 		tmplist = g_list_append(tmplist, "javascript1.2");
 		tmplist = g_list_append(tmplist, "javascript1.1");
@@ -2017,25 +1965,6 @@ static void script_link_cb(gint type, Tbfwin *bfwin, Ttagpopup *data) {
 		tmplist2 = g_list_append(NULL, "application/javascript");
 		tmplist2 = g_list_append(NULL, "text/javascript");
 		tmplist2 = g_list_append(tmplist2, "application/x-javascript");
-	} else {
-		tmplist = g_list_append(NULL, "stylesheet");
-		tmplist = g_list_append(tmplist, "alternate");
-		tmplist = g_list_append(tmplist, "start");
-		tmplist = g_list_append(tmplist, "next");
-		tmplist = g_list_append(tmplist, "prev");
-		tmplist = g_list_append(tmplist, "contents");
-		tmplist = g_list_append(tmplist, "index");
-		tmplist = g_list_append(tmplist, "glossary");
-		tmplist = g_list_append(tmplist, "copyright");
-		tmplist = g_list_append(tmplist, "chapter");
-		tmplist = g_list_append(tmplist, "section");
-		tmplist = g_list_append(tmplist, "subsection");
-		tmplist = g_list_append(tmplist, "appendix");
-		tmplist = g_list_append(tmplist, "help");
-		tmplist = g_list_append(tmplist, "bookmark");
-		label = gtk_label_new_with_mnemonic(_("_Rel:"));
-		tmplist2 = g_list_append(NULL, "text/css");
-	}
 	tmplist2 = g_list_append(tmplist2, "text/plain");
 	tmplist2 = g_list_append(tmplist2, "text/html");
 
@@ -2054,19 +1983,98 @@ static void script_link_cb(gint type, Tbfwin *bfwin, Ttagpopup *data) {
 	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[1], 0, 0.5, dgtable, 0, 2, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 2, 10, 3, 4);
 
-	if (type == 0) {
-		html_diag_finish(dg, G_CALLBACK(scriptok_lcb));
-	} else {
-		html_diag_finish(dg, G_CALLBACK(linkok_lcb));
-	}
+	html_diag_finish(dg, G_CALLBACK(scriptok_lcb));
 	g_list_free(tmplist);
 	g_list_free(tmplist2);
 }
 
-void script_dialog(Tbfwin *bfwin, Ttagpopup *data) {
-	script_link_cb(0, bfwin, data);
+static void linkdialogok_lcb(GtkWidget * widget, Thtml_diag *dg) {
+	gchar *thestring, *finalstring;
+
+	thestring = g_strdup(cap("<LINK"));
+	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(dg->attrwidget[0])->entry), cap("HREF"), thestring, NULL);
+	thestring = insert_string_if_entry(GTK_WIDGET(dg->attrwidget[1]), cap("HREFLANG"), thestring, NULL);
+	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(dg->attrwidget[2])->entry), cap("TYPE"), thestring, NULL);
+	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(dg->attrwidget[3])->entry), cap("REL"), thestring, NULL);
+	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(dg->attrwidget[4])->entry), cap("REV"), thestring, NULL);
+	thestring = insert_string_if_entry(GTK_WIDGET(GTK_COMBO(dg->attrwidget[5])->entry), cap("MEDIA"), thestring, NULL);
+	thestring = insert_string_if_entry(GTK_WIDGET(dg->attrwidget[6]), cap("LANG"), thestring, NULL);
+	finalstring = g_strconcat(thestring, (main_v->props.xhtml == 1) ? " />" : ">", NULL);
+	g_free(thestring);
+
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, NULL);
+	} else {
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
+	}
+	g_free(finalstring);
+	html_diag_destroy_cb(NULL, dg);
 }
 
-void link_dialog(Tbfwin *bfwin, Ttagpopup *data) {
-	script_link_cb(1, bfwin, data);
-}
+void linkdialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
+	static gchar *tagitems[] = {"href", "hreflang", "type", "rel", "rev", "media", "lang", NULL };
+	gchar *tagvalues[8];
+	gchar *custom = NULL;
+	Thtml_diag *dg;
+	GtkWidget *dgtable, *but;
+	
+	dg = html_diag_new(bfwin,_("Link"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
+	dgtable = html_diag_table_in_vbox(dg, 3, 10);
+	{
+		GList *rel_link_list=NULL, *tmplist;
+		rel_link_list = list_relative_document_filenames(bfwin->current_document);
+		tmplist = duplicate_stringlist(bfwin->session->urllist, 1);
+		rel_link_list = g_list_concat(tmplist, rel_link_list);
+		dg->attrwidget[0] = combo_with_popdown(tagvalues[0], rel_link_list, 1);
+		free_stringlist(rel_link_list);
+	}
+	bf_mnemonic_label_tad_with_alignment(_("_Href:"), dg->attrwidget[0], 0, 0.5, dgtable, 0, 1, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->attrwidget[0], 1, 2, 0, 1);
+	but = file_but_new(GTK_COMBO(dg->attrwidget[0])->entry, 0, bfwin);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), but, 2, 3, 0, 1);
+
+	dg->attrwidget[1] = entry_with_text(tagvalues[1], 1024);
+	bf_mnemonic_label_tad_with_alignment(_("Href_lang:"), dg->attrwidget[1], 0, 0.5, dgtable, 0, 1, 1, 2);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->attrwidget[1], 1, 3, 1, 2);
+
+	{
+		GList *tmplist = list_from_arglist(FALSE, "text/html", "text/css", "text/plain", "text/javascript", "application/postscript", NULL);
+		dg->attrwidget[2] = combo_with_popdown(tagvalues[2], tmplist, 1);
+		g_list_free(tmplist);
+	}
+	bf_mnemonic_label_tad_with_alignment(_("_Type:"), dg->attrwidget[2], 0, 0.5, dgtable, 0, 1, 2, 3);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->attrwidget[2], 1, 3, 2, 3);
+	
+	{
+		GList *tmplist = list_from_arglist(FALSE, "Alternate", "Stylesheet", "Start", "Next", "Prev", "Contents", "Index", "Glossary", "Copyright", "Chapter", "Section", "Subsection", "Appendix", "Help", "Bookmark", NULL);
+		dg->attrwidget[3] = combo_with_popdown(tagvalues[3], tmplist, 1);
+		bf_mnemonic_label_tad_with_alignment(_("_Forward Relation:"), dg->attrwidget[3], 0, 0.5, dgtable, 0, 1, 3, 4);
+		gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->attrwidget[3], 1, 3, 3, 4);
+		
+		dg->attrwidget[4] = combo_with_popdown(tagvalues[4], tmplist, 1);
+		bf_mnemonic_label_tad_with_alignment(_("_Reverse Relation:"), dg->attrwidget[4], 0, 0.5, dgtable, 0, 1, 4, 5);
+		gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->attrwidget[4], 1, 3, 4, 5);
+		
+		g_list_free(tmplist);
+	}
+	
+	{
+		GList *tmplist = list_from_arglist(FALSE, "screen", "tty", "tv", "projection", "handheld", "print", "braille", "aural", "all", NULL);
+		dg->attrwidget[5] = combo_with_popdown(tagvalues[5], tmplist, 1);
+		g_list_free(tmplist);
+	}
+	bf_mnemonic_label_tad_with_alignment(_("Media:"), dg->attrwidget[5], 0, 0.5, dgtable, 0, 1, 5, 6);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->attrwidget[5], 1, 3, 5, 6);
+
+	dg->attrwidget[6] = entry_with_text(tagvalues[6], 1024);
+	bf_mnemonic_label_tad_with_alignment(_("L_ang:"), dg->attrwidget[6], 0, 0.5, dgtable, 0, 1, 6, 7);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->attrwidget[6], 1, 3, 6, 7);
+	
+	dg->attrwidget[7] = entry_with_text(custom, 1024);
+	bf_mnemonic_label_tad_with_alignment(_("_Custom:"), dg->attrwidget[7], 0, 0.5, dgtable, 0, 1, 7, 8);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->attrwidget[7], 1, 3, 7, 8);
+	
+	html_diag_finish(dg, G_CALLBACK(linkdialogok_lcb));
+	if (custom)	g_free(custom);
+}	
