@@ -39,8 +39,6 @@ enum {
 	view_main_toolbar,
 	view_left_panel,
 	view_line_numbers,
-	filebrowser_show_hidden_files,
-	filebrowser_show_backup_files,
 	filebrowser_two_pane_view,
 	filebrowser_unknown_icon,
 	filebrowser_dir_icon,
@@ -77,10 +75,12 @@ enum {
 	ext_browsers_in_submenu,
 	ext_commands_in_submenu,
 	ext_outputbox_in_submenu,
+	bookmarks_sort,
+	bookmarks_default_store,
+	bookmarks_filename_mode,
 	document_tabposition,
 	leftpanel_tabposition,
 	default_basedir,
-	cont_highlight_full, 	/* if you want to highlight the full text or just the line */
 	/* not yet in use */
 	image_editor_cline, 	/* image editor commandline */
 	full_p,				/* use </p> */
@@ -98,11 +98,8 @@ enum {
 	lowercase_tags,		/* use lowercase tags */
 	word_wrap,				/* use wordwrap */
 	autoindent,			/* autoindent code */
-	fontset,				/* load fontset (0 = load font) */
-	force_def_style,  /* force white editor background */
 	drop_at_drop_pos, 	/* drop at drop position instead of cursor position */
 	link_management, 	/* perform link management */
-	cont_highlight_update,	/* update the syntax highlighting continuous */
 	html_ver,
 	cust_menu, 		/* entries in the custom menu */
 #ifdef WITH_SPC
@@ -128,6 +125,9 @@ enum {
 #ifdef WITH_MSG_QUEUE
 	open_in_running_bluefish, /* open commandline documents in already running session*/
 #endif /* WITH_MSG_QUEUE */
+#ifdef HAVE_GNOME_VFS
+	server_zope_compat,
+#endif /* HAVE_GNOME_VFS */
 	property_num_max
 };
 
@@ -373,13 +373,13 @@ static gchar **generic_create_strarr(gint numitems, GtkWidget **entries, gboolea
 		g_free(newtype);
 	}
 } */
-
+/*
 static gchar **filetype_create_strarr(Tprefdialog *pd) {
 	gchar **strarr;
 	gchar *escaped, *tmp;
 	tmp = gtk_editable_get_chars(GTK_EDITABLE(pd->ftd.entry[0]),0,-1);
 	if (strlen(tmp)) {
-		strarr = g_malloc(7*sizeof(gchar *));
+		strarr = g_malloc(8*sizeof(gchar *));
 		strarr[0] = tmp;
 		strarr[1] = gtk_editable_get_chars(GTK_EDITABLE(pd->ftd.entry[1]),0,-1);
 		escaped = gtk_editable_get_chars(GTK_EDITABLE(pd->ftd.entry[2]),0,-1);
@@ -388,7 +388,8 @@ static gchar **filetype_create_strarr(Tprefdialog *pd) {
 		strarr[3] = gtk_editable_get_chars(GTK_EDITABLE(pd->ftd.entry[3]),0,-1);
 		strarr[4] = g_strdup(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pd->ftd.entry[4])) ? "1" : "0");
 		strarr[5] = gtk_editable_get_chars(GTK_EDITABLE(pd->ftd.entry[5]),0,-1);
-		strarr[6] = NULL;
+		strarr[6] = g_strdup("1");
+		strarr[7] = NULL;
 		DEBUG_MSG("filetype_create_strarr, created at %p\n", strarr);
 		return strarr;
 	} else {
@@ -400,7 +401,7 @@ static gchar **filetype_create_strarr(Tprefdialog *pd) {
 static void set_filetype_strarr_in_list(GtkTreeIter *iter, gchar **strarr, Tprefdialog *pd) {
 	gint arrcount;
 	arrcount = count_array(strarr);
-	if (arrcount==6) {
+	if (arrcount==7) {
 		gchar *escaped;
 		DEBUG_MSG("set_filetype_strarr_in_list, escaping %s\n",strarr[2]);
 		escaped = escape_string(strarr[2],FALSE);
@@ -412,32 +413,18 @@ static void set_filetype_strarr_in_list(GtkTreeIter *iter, gchar **strarr, Tpref
 			,3,strarr[3]
 			,4,(strarr[4][0] != '0')
 			,5,strarr[5]
+			,6,strarr[6]
+			,7,strarr
 			,-1);
 		g_free(escaped);
 	}
 }
 
-static void add_new_filetype_lcb(GtkWidget *wid, Tprefdialog *pd) {
-/*	add_new_general_lcb(pd, pd->ftd.entry[0],4,filetypes,GTK_LIST_STORE(pd->ftd.lstore));*/
-	gchar **strarr;
-	strarr = filetype_create_strarr(pd);
-	if (strarr) {
-		GtkTreeIter iter;
-		pd->ftd.curstrarr = strarr;
-		pd->lists[filetypes] = g_list_append(pd->lists[filetypes], strarr);
-		DEBUG_MSG("add_new_filetype_lcb, added %p to list\n",strarr);
-		gtk_list_store_append(GTK_LIST_STORE(pd->ftd.lstore), &iter);
-		set_filetype_strarr_in_list(&iter,strarr,pd);
-		DEBUG_MSG("add_new_filetype_lcb, set %p to liststore\n",strarr);
-		gtk_tree_selection_select_iter(gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->ftd.lview)),&iter);
-	}
-}
-
 static void filetype_apply_changes(Tprefdialog *pd) {
 	DEBUG_MSG("filetype_apply_changes, started\n");
 	if (pd->ftd.curstrarr) {
 		GtkTreeIter iter;
-		gboolean retval = TRUE;
+		gboolean retval;
 		GList *tmplist;
 		tmplist = g_list_first(pd->lists[filetypes]);
 		while (tmplist) {
@@ -451,7 +438,7 @@ static void filetype_apply_changes(Tprefdialog *pd) {
 			tmplist = g_list_next(tmplist);
 		}
 		
-		gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->ftd.lstore),&iter);
+		retval = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->ftd.lstore),&iter);
 		DEBUG_MSG("filetype_apply_changes, searching for '%s' in liststore\n",pd->ftd.curstrarr[0]);
 		while (retval) {
 			gchar *curval;
@@ -469,7 +456,6 @@ static void filetype_apply_changes(Tprefdialog *pd) {
 }
 
 static void filetype_selection_changed_cb(GtkTreeSelection *selection, Tprefdialog *pd) {
-/*	generic_selection_changed_cb(selection,pd->ftd.entry,filetype_apply_changes,pd,filetypes,4,&pd->ftd.curstrarr);*/
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	DEBUG_MSG("filetype_selection_changed_cb, started\n");
@@ -500,48 +486,146 @@ static void filetype_selection_changed_cb(GtkTreeSelection *selection, Tprefdial
 		DEBUG_MSG("filetype_selection_changed_cb, no selection ?!?!\n");
 	}
 }
+*/
+static void set_filetype_strarr_in_list(GtkTreeIter *iter, gchar **strarr, Tprefdialog *pd) {
+	gint arrcount;
+	arrcount = count_array(strarr);
+	if (arrcount==7) {
+		gchar *escaped;
+		escaped = escape_string(strarr[2],FALSE);
+		gtk_list_store_set(GTK_LIST_STORE(pd->ftd.lstore), iter
+				,0,strarr[0],1,strarr[1],2,escaped,3,strarr[3]
+				,4,(strarr[4][0] != '0'),5,strarr[5],6,strarr[6]
+				,7,strarr,-1);
+		g_free(escaped);
+	}
+}
+
+/* type 0=escapedtext, 1=text, 2=toggle */
+static void filetype_apply_change(Tprefdialog *pd, gint type, gchar *path, gchar *newval, gint index) {
+	gchar **strarr;
+	GtkTreeIter iter;
+	GtkTreePath* tpath = gtk_tree_path_new_from_string(path);
+	gtk_tree_model_get_iter(GTK_TREE_MODEL(pd->ftd.lstore),&iter,tpath);
+	gtk_tree_model_get(GTK_TREE_MODEL(pd->ftd.lstore), &iter, 7, &strarr, -1);
+	if (type ==1) {
+		gtk_list_store_set(GTK_LIST_STORE(pd->ftd.lstore),&iter,index,newval,-1);
+	} else {
+		gtk_list_store_set(GTK_LIST_STORE(pd->ftd.lstore),&iter,index,(newval[0] == '1'),-1);
+	}
+	if (strarr[index]) g_free(strarr[index]);
+	if (type == 0) {
+		strarr[index] = g_strdup(newval);
+	} else {
+		strarr[index] = unescape_string(newval, FALSE);
+	}
+	gtk_tree_path_free(tpath);
+}
+static void filetype_0_edited_lcb(GtkCellRendererText *cellrenderertext,gchar *path,gchar *newtext,Tprefdialog *pd) {
+	filetype_apply_change(pd, 1, path, newtext, 0);
+}
+static void filetype_1_edited_lcb(GtkCellRendererText *cellrenderertext,gchar *path,gchar *newtext,Tprefdialog *pd) {
+	filetype_apply_change(pd, 1, path, newtext, 1);
+}
+static void filetype_2_edited_lcb(GtkCellRendererText *cellrenderertext,gchar *path,gchar *newtext,Tprefdialog *pd) {
+	filetype_apply_change(pd, 1, path, newtext, 2);
+}
+static void filetype_3_edited_lcb(GtkCellRendererText *cellrenderertext,gchar *path,gchar *newtext,Tprefdialog *pd) {
+	filetype_apply_change(pd, 1, path, newtext, 3);
+}
+static void filetype_4_toggled_lcb(GtkCellRendererToggle *cellrenderertoggle,gchar *path,Tprefdialog *pd) {
+	gchar *val = g_strdup(cellrenderertoggle->active ? "0" : "1");
+	filetype_apply_change(pd, 2, path, val, 4);
+	g_free(val);
+}
+static void filetype_5_edited_lcb(GtkCellRendererText *cellrenderertext,gchar *path,gchar *newtext,Tprefdialog *pd) {
+	filetype_apply_change(pd, 1, path, newtext, 5);
+}
+static void filetype_6_edited_lcb(GtkCellRendererText *cellrenderertext,gchar *path,gchar *newtext,Tprefdialog *pd) {
+	if (strlen(newtext)==1 && newtext[0] >= '0' && newtext[0] <= '2') {
+		filetype_apply_change(pd, 1, path, newtext, 6);
+	}
+}
+/* type 0/1=text, 2=toggle */
+static void filetype_create_column(GtkTreeView *treeview, gint type, GCallback func, gpointer data, const gchar *title, gint num) {
+	GtkTreeViewColumn *column;
+	GtkCellRenderer *renderer;
+	if (type == 1 || type == 0) {
+		renderer = gtk_cell_renderer_text_new();
+		g_object_set(G_OBJECT(renderer), "editable", TRUE, NULL);
+		g_signal_connect(G_OBJECT(renderer), "edited", func, data);
+	} else {
+		renderer = gtk_cell_renderer_toggle_new();
+		g_object_set(G_OBJECT(renderer), "activatable", TRUE, NULL);
+		g_signal_connect(G_OBJECT(renderer), "toggled", func, data);
+	}
+	column = gtk_tree_view_column_new_with_attributes(title, renderer,(type ==1) ? "text" : "active" ,num,NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
+}
+
+static void add_new_filetype_lcb(GtkWidget *wid, Tprefdialog *pd) {
+	gchar **strarr;
+	gint i;
+	GtkTreeIter iter;
+	strarr = g_malloc0(8*sizeof(gchar *));
+	for (i=0;i<7;i++) {
+		strarr[i] = g_strdup("");
+	}
+	strarr[7] = NULL;
+	gtk_list_store_append(GTK_LIST_STORE(pd->ftd.lstore), &iter);
+	set_filetype_strarr_in_list(&iter, strarr,pd);
+	pd->lists[filetypes] = g_list_append(pd->lists[filetypes], strarr);
+}
+static void delete_filetype_lcb(GtkWidget *wid, Tprefdialog *pd) {
+	GtkTreeIter iter;
+	GtkTreeSelection *select = gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->ftd.lview));
+	if (gtk_tree_selection_get_selected (select,NULL,&iter)) {
+		gchar **strarr;
+		gtk_tree_model_get(GTK_TREE_MODEL(pd->ftd.lstore), &iter, 7, &strarr, -1);
+		gtk_list_store_remove(GTK_LIST_STORE(pd->ftd.lstore),&iter);
+		pd->lists[filetypes] = g_list_remove(pd->lists[filetypes], strarr);
+		g_strfreev(strarr);
+	}
+}
+/*
+static void filetype_reordered_lcb(GtkTreeModel *treemodel,GtkTreePath *arg1,GtkTreeIter *arg2,
+			gpointer arg3,Tprefdialog *pd) {
+	gchar *tmp = gtk_tree_path_to_string(arg1);
+	g_print("filetype_reordered_lcb, called %s\n",tmp);
+	g_free(tmp);
+}*/
 
 static void create_filetype_gui(Tprefdialog *pd, GtkWidget *vbox1) {
-	GtkWidget *hbox, *but;
+	GtkWidget *hbox, *but, *scrolwin;
 	pd->lists[filetypes] = duplicate_arraylist(main_v->props.filetypes);
-
-	pd->ftd.lstore = gtk_list_store_new (6,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_BOOLEAN,G_TYPE_STRING);
+	pd->ftd.lstore = gtk_list_store_new (8,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_BOOLEAN,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_POINTER);
 	pd->ftd.lview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pd->ftd.lstore));
-	{
-		GtkTreeViewColumn *column;
-		GtkWidget *scrolwin;
-		GtkTreeSelection *select;
-	   GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
-		GtkCellRenderer *renderertoggle = gtk_cell_renderer_toggle_new();
-		column = gtk_tree_view_column_new_with_attributes (_("Filetype"), renderer,"text",0,NULL);
-		gtk_tree_view_append_column (GTK_TREE_VIEW(pd->ftd.lview), column);
-		column = gtk_tree_view_column_new_with_attributes (_("Extensions"), renderer,"text",1,NULL);
-		gtk_tree_view_append_column (GTK_TREE_VIEW(pd->ftd.lview), column);
-		column = gtk_tree_view_column_new_with_attributes (_("Update chars"), renderer,"text",2,NULL);
-		gtk_tree_view_append_column (GTK_TREE_VIEW(pd->ftd.lview), column);
-		column = gtk_tree_view_column_new_with_attributes (_("Icon"), renderer,"text",3,NULL);
-		gtk_tree_view_append_column (GTK_TREE_VIEW(pd->ftd.lview), column);
-		
-		column = gtk_tree_view_column_new_with_attributes (_("Editable"), renderertoggle,"active",4,NULL);
-		gtk_tree_view_append_column (GTK_TREE_VIEW(pd->ftd.lview), column);
-		column = gtk_tree_view_column_new_with_attributes (_("Content regex"), renderer,"text",5,NULL);
-		gtk_tree_view_append_column (GTK_TREE_VIEW(pd->ftd.lview), column);
-		scrolwin = gtk_scrolled_window_new(NULL, NULL);
-		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolwin),GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
-		gtk_container_add(GTK_CONTAINER(scrolwin), pd->ftd.lview);
-		gtk_widget_set_usize(scrolwin, 150, 150);
-		gtk_box_pack_start(GTK_BOX(vbox1), scrolwin, TRUE, TRUE, 2);
-		
-		select = gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->ftd.lview));
-		g_signal_connect(G_OBJECT(select), "changed",G_CALLBACK(filetype_selection_changed_cb),pd);
-	}
+	filetype_create_column(GTK_TREE_VIEW(pd->ftd.lview), 1, G_CALLBACK(filetype_0_edited_lcb), pd, _("Filetype"), 0);
+	filetype_create_column(GTK_TREE_VIEW(pd->ftd.lview), 1, G_CALLBACK(filetype_1_edited_lcb), pd, _("Extensions"), 1);
+	filetype_create_column(GTK_TREE_VIEW(pd->ftd.lview), 1, G_CALLBACK(filetype_2_edited_lcb), pd, _("Update chars"), 2);
+	filetype_create_column(GTK_TREE_VIEW(pd->ftd.lview), 1, G_CALLBACK(filetype_3_edited_lcb), pd, _("Icon"), 3);
+	filetype_create_column(GTK_TREE_VIEW(pd->ftd.lview), 2, G_CALLBACK(filetype_4_toggled_lcb), pd, _("Editable"), 4);
+	filetype_create_column(GTK_TREE_VIEW(pd->ftd.lview), 1, G_CALLBACK(filetype_5_edited_lcb), pd, _("Content regex"), 5);
+	filetype_create_column(GTK_TREE_VIEW(pd->ftd.lview), 1, G_CALLBACK(filetype_6_edited_lcb), pd, _("Auto close tags mode"), 6);
+
+	scrolwin = gtk_scrolled_window_new(NULL, NULL);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolwin),GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
+	gtk_container_add(GTK_CONTAINER(scrolwin), pd->ftd.lview);
+	gtk_widget_set_size_request(scrolwin, 150, 190);
+	gtk_box_pack_start(GTK_BOX(vbox1), scrolwin, TRUE, TRUE, 2);
+/*	gtk_tree_view_set_reorderable(GTK_TREE_VIEW(pd->ftd.lview), TRUE);
+	g_signal_connect(G_OBJECT(pd->ftd.lstore), "rows-reordered", G_CALLBACK(filetype_reordered_lcb), pd);*/
+	
+/*	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->ftd.lview));
+	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
+	g_signal_connect(G_OBJECT(select), "changed",G_CALLBACK(filetype_selection_changed_cb),pd);*/
 	{
 		GList *tmplist = g_list_first(pd->lists[filetypes]);
 		while (tmplist) {
 			gint arrcount;
 			gchar **strarr = (gchar **)tmplist->data;
 			arrcount = count_array(strarr);
-			if (arrcount==6) {
+			if (arrcount==7) {
 				GtkTreeIter iter;
 				gtk_list_store_append(GTK_LIST_STORE(pd->ftd.lstore), &iter);
 				set_filetype_strarr_in_list(&iter, strarr,pd);
@@ -551,19 +635,10 @@ static void create_filetype_gui(Tprefdialog *pd, GtkWidget *vbox1) {
 	}
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1),hbox, TRUE, TRUE, 2);
-	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new(_("Filetype")), FALSE, FALSE, 2);
-	pd->ftd.entry[0] = entry_with_text(NULL, 100);
-	gtk_box_pack_start(GTK_BOX(hbox),pd->ftd.entry[0], TRUE, TRUE, 2);
 	but = bf_gtkstock_button(GTK_STOCK_ADD, G_CALLBACK(add_new_filetype_lcb), pd);
 	gtk_box_pack_start(GTK_BOX(hbox),but, FALSE, FALSE, 2);
-/*	but = bf_gtkstock_button(GTK_STOCK_DELETE, G_CALLBACK(filetype_delete_clicked_lcb), pd);
-	gtk_box_pack_start(GTK_BOX(hbox),but, FALSE, FALSE, 2);*/
-
-	pd->ftd.entry[1] = boxed_full_entry(_("Extensions (colon separated)"), NULL, 500, vbox1);
-	pd->ftd.entry[2] = boxed_full_entry(_("Highlight update characters"), NULL, 500, vbox1);
-	pd->ftd.entry[3] = prefs_string(_("Icon"), NULL, vbox1, pd, string_file);
-	pd->ftd.entry[4] = boxed_checkbut_with_value(_("Editable"), TRUE, vbox1);
-	pd->ftd.entry[5] = boxed_full_entry(_("Content regex pattern"), NULL, 500, vbox1);
+	but = bf_gtkstock_button(GTK_STOCK_DELETE, G_CALLBACK(delete_filetype_lcb), pd);
+	gtk_box_pack_start(GTK_BOX(hbox),but, FALSE, FALSE, 2);
 }
 
 static gchar **filefilter_create_strarr(Tprefdialog *pd) {
@@ -587,9 +662,7 @@ static void filefilter_apply_changes(Tprefdialog *pd) {
 		if (strarr) {
 			GList *tmplist;
 			GtkTreeIter iter;
-			gboolean retval = TRUE;
-
-			gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->ffd.lstore),&iter);
+			gboolean retval = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->ffd.lstore),&iter);
 			while (retval) {
 				gchar *curval;
 				gtk_tree_model_get(GTK_TREE_MODEL(pd->ffd.lstore),&iter,0,&curval,-1);
@@ -686,7 +759,7 @@ static void create_filefilter_gui(Tprefdialog *pd, GtkWidget *vbox1) {
 		scrolwin = gtk_scrolled_window_new(NULL, NULL);
 		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolwin),GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
 		gtk_container_add(GTK_CONTAINER(scrolwin), pd->ffd.lview);
-		gtk_widget_set_usize(scrolwin, 150, 150);
+		gtk_widget_set_size_request(scrolwin, 150, 150);
 		gtk_box_pack_start(GTK_BOX(vbox1), scrolwin, TRUE, TRUE, 2);
 		
 		select = gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->ffd.lview));
@@ -786,14 +859,13 @@ static void highlightpattern_popmenu_activate(GtkMenuItem *menuitem,Tprefdialog
 
 	DEBUG_MSG("highlightpattern_popmenu_activate, pd=%p, menuitem=%p\n", pd, menuitem);
 	tmplist = g_list_first(pd->lists[highlight_patterns]);
+	highlightpattern_apply_changes(pd);
 	if (menuitem) {
 		pd->hpd.selected_filetype = gtk_label_get_text(GTK_LABEL(GTK_BIN(menuitem)->child));
 	}
-
-	highlightpattern_apply_changes(pd);
-
+	DEBUG_MSG("highlightpattern_popmenu_activate, applied changes, about to clear liststore\n");
 	gtk_list_store_clear(GTK_LIST_STORE(pd->hpd.lstore));
-	DEBUG_MSG("highlightpattern_popmenu_activate, cleared and applied changes\n");
+	DEBUG_MSG("highlightpattern_popmenu_activate, about to fill for filetype %s (tmplist=%p)\n",pd->hpd.selected_filetype,tmplist);
 	/* fill list model here */
 	while (tmplist) {
 		gchar **strarr =(gchar **)tmplist->data;
@@ -893,6 +965,8 @@ static void highlightpattern_selection_changed_cb(GtkTreeSelection *selection, T
 			tmplist = g_list_next(tmplist);
 		}
 		g_free(pattern);
+	} else {
+		DEBUG_MSG("no selection, returning..\n");
 	}
 }
 static void highlightpattern_type_toggled(GtkToggleButton *togglebutton,Tprefdialog *pd){
@@ -1101,9 +1175,7 @@ static void browsers_apply_changes(Tprefdialog *pd) {
 		if (strarr) {
 			GList *tmplist;
 			GtkTreeIter iter;
-			gboolean retval = TRUE;
-
-			gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->bd.lstore),&iter);
+			gboolean retval = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->bd.lstore),&iter);
 			while (retval) {
 				gchar *curval;
 				gtk_tree_model_get(GTK_TREE_MODEL(pd->bd.lstore),&iter,0,&curval,-1);
@@ -1154,8 +1226,7 @@ static void add_new_browser_lcb(GtkWidget *wid, Tprefdialog *pd) {
 static void delete_browser_lcb(GtkWidget *wid, Tprefdialog *pd) {
 	if (pd->bd.curstrarr) {
 		GtkTreeIter iter;
-		gboolean retval=TRUE;
-		gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->bd.lstore),&iter);
+		gboolean retval= gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->bd.lstore),&iter);
 		while (retval) {
 			gchar *curval;
 			gtk_tree_model_get(GTK_TREE_MODEL(pd->bd.lstore),&iter,0,&curval,-1);
@@ -1172,8 +1243,7 @@ static void delete_browser_lcb(GtkWidget *wid, Tprefdialog *pd) {
 static void set_default_browser_lcb(GtkWidget *wid, Tprefdialog *pd) {
 	if (pd->bd.curstrarr) {
 		GtkTreeIter iter;
-		gboolean retval=TRUE;
-		gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->bd.lstore),&iter);
+		gboolean retval=gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->bd.lstore),&iter);
 		while (retval) {
 			gchar *curval;
 			gtk_tree_model_get(GTK_TREE_MODEL(pd->bd.lstore),&iter,0,&curval,-1);
@@ -1242,7 +1312,7 @@ static void create_browsers_gui(Tprefdialog *pd, GtkWidget *vbox1) {
 		scrolwin = gtk_scrolled_window_new(NULL, NULL);
 		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolwin),GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
 		gtk_container_add(GTK_CONTAINER(scrolwin), pd->bd.lview);
-		gtk_widget_set_usize(scrolwin, 150, 150);
+		gtk_widget_set_size_request(scrolwin, 120, 120);
 		gtk_box_pack_start(GTK_BOX(vbox1), scrolwin, TRUE, TRUE, 2);
 		
 		select = gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->bd.lview));
@@ -1294,9 +1364,7 @@ static void externals_apply_changes(Tprefdialog *pd) {
 		if (strarr) {
 			GList *tmplist;
 			GtkTreeIter iter;
-			gboolean retval = TRUE;
-
-			gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->ed.lstore),&iter);
+			gboolean retval = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->ed.lstore),&iter);
 			while (retval) {
 				gchar *curval;
 				gtk_tree_model_get(GTK_TREE_MODEL(pd->ed.lstore),&iter,0,&curval,-1);
@@ -1349,6 +1417,34 @@ static void add_new_external_lcb(GtkWidget *wid, Tprefdialog *pd) {
 	}
 }
 
+static void delete_external_commands_lcb(GtkWidget *wid, Tprefdialog *pd) {
+	GtkTreeSelection *select;
+	GtkTreeIter iter;
+	gboolean retval;
+
+	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->ed.lview));
+	retval = gtk_tree_selection_get_selected (select,NULL,&iter);
+	if(retval) {
+		gchar *curval;
+		GList *work = NULL;
+		gchar **curstrarr;
+		
+		gtk_tree_model_get(GTK_TREE_MODEL(pd->ed.lstore),&iter,0,&curval,-1);
+		gtk_list_store_remove(pd->ed.lstore,&iter);
+		/* we delete the selected element from list */
+		work = pd->lists[external_commands];
+		while(work) {
+			curstrarr = work->data;
+			if (strcmp(curval,curstrarr[0])==0) {
+				pd->lists[external_commands] = g_list_remove(pd->lists[external_commands],curstrarr);
+				break;
+			}
+			work = g_list_next(work);
+		}
+		g_free(curval);
+	}
+}
+
 static void create_externals_gui(Tprefdialog *pd, GtkWidget *vbox1) {
 	GtkWidget *hbox, *but;
 	pd->lists[external_commands] = duplicate_arraylist(main_v->props.external_commands);
@@ -1368,7 +1464,7 @@ static void create_externals_gui(Tprefdialog *pd, GtkWidget *vbox1) {
 		scrolwin = gtk_scrolled_window_new(NULL, NULL);
 		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolwin),GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
 		gtk_container_add(GTK_CONTAINER(scrolwin), pd->ed.lview);
-		gtk_widget_set_usize(scrolwin, 150, 150);
+		gtk_widget_set_size_request(scrolwin, 120, 120);
 		gtk_box_pack_start(GTK_BOX(vbox1), scrolwin, TRUE, TRUE, 2);
 		
 		select = gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->ed.lview));
@@ -1389,7 +1485,12 @@ static void create_externals_gui(Tprefdialog *pd, GtkWidget *vbox1) {
 			tmplist = g_list_next(tmplist);
 		}
 	}
-	
+	hbox = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox1), hbox, TRUE, TRUE, 0);
+	but = bf_gtkstock_button(GTK_STOCK_DELETE, G_CALLBACK(delete_external_commands_lcb), pd);
+	gtk_box_pack_start(GTK_BOX(hbox), but, FALSE, TRUE, 3);
+
+	gtk_box_pack_start(GTK_BOX(vbox1), gtk_hseparator_new(), TRUE, TRUE, 0);
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(_("Label")), FALSE, TRUE, 3);
@@ -1420,9 +1521,7 @@ static void outputbox_apply_changes(Tprefdialog *pd) {
 		if (strarr) {
 			GList *tmplist;
 			GtkTreeIter iter;
-			gboolean retval = TRUE;
-
-			gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->od.lstore),&iter);
+			gboolean retval = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(pd->od.lstore),&iter);
 			while (retval) {
 				gchar *curval;
 				gtk_tree_model_get(GTK_TREE_MODEL(pd->od.lstore),&iter,0,&curval,-1);
@@ -1536,7 +1635,7 @@ static void create_outputbox_gui(Tprefdialog *pd, GtkWidget *vbox1) {
 		scrolwin = gtk_scrolled_window_new(NULL, NULL);
 		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolwin),GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
 		gtk_container_add(GTK_CONTAINER(scrolwin), pd->od.lview);
-		gtk_widget_set_usize(scrolwin, 150, 150);
+		gtk_widget_set_size_request(scrolwin, 150, 150);
 		gtk_box_pack_start(GTK_BOX(vbox1), scrolwin, TRUE, TRUE, 2);
 		
 		select = gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->od.lview));
@@ -1584,6 +1683,18 @@ static void create_outputbox_gui(Tprefdialog *pd, GtkWidget *vbox1) {
 static void preferences_destroy_lcb(GtkWidget * widget, Tprefdialog *pd) {
 	GtkTreeSelection *select;
 	DEBUG_MSG("preferences_destroy_lcb, started\n");
+
+	free_arraylist(pd->lists[filetypes]);
+	free_arraylist(pd->lists[filefilters]);
+	free_arraylist(pd->lists[highlight_patterns]);
+	free_arraylist(pd->lists[browsers]);
+	free_arraylist(pd->lists[external_commands]);
+	pd->lists[filetypes] = NULL;
+	pd->lists[filefilters] = NULL;
+	pd->lists[highlight_patterns] = NULL;
+	pd->lists[browsers] = NULL;
+	pd->lists[external_commands] = NULL;
+
 	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(pd->ftd.lview));
 	g_signal_handlers_destroy(G_OBJECT(select));
 /* g_signal_handlers_destroy(G_OBJECT(GTK_COMBO(pd->ftd.combo)->list));*/
@@ -1602,7 +1713,7 @@ static void preferences_destroy_lcb(GtkWidget * widget, Tprefdialog *pd) {
 	window_destroy(pd->win);
 	g_free(pd);
 }
-static void preferences_ok_clicked_lcb(GtkWidget *wid, Tprefdialog *pd) {
+static void preferences_apply(Tprefdialog *pd) {
 	string_apply(&main_v->props.editor_font_string, pd->prefs[editor_font_string]);
 	integer_apply(&main_v->props.editor_tab_width, pd->prefs[editor_tab_width], FALSE);
 	integer_apply(&main_v->props.editor_indent_wspaces, pd->prefs[editor_indent_wspaces], TRUE);
@@ -1610,11 +1721,19 @@ static void preferences_ok_clicked_lcb(GtkWidget *wid, Tprefdialog *pd) {
 	integer_apply(&main_v->props.view_line_numbers, pd->prefs[view_line_numbers], TRUE);
 	integer_apply(&main_v->props.defaulthighlight, pd->prefs[defaulthighlight], TRUE);
 	integer_apply(&main_v->props.highlight_num_lines_count, pd->prefs[highlight_num_lines_count], FALSE);
-	integer_apply(&main_v->props.cont_highlight_full, pd->prefs[cont_highlight_full], TRUE);
 
-	integer_apply(&main_v->props.lowercase_tags, pd->prefs[lowercase_tags], TRUE);
-	integer_apply(&main_v->props.allow_dep, pd->prefs[allow_dep], TRUE);
+	integer_apply(&main_v->props.bookmarks_sort, pd->prefs[bookmarks_sort], TRUE);
+	integer_apply(&main_v->props.bookmarks_default_store, pd->prefs[bookmarks_default_store], TRUE);
+	main_v->props.bookmarks_filename_mode = gtk_option_menu_get_history(GTK_OPTION_MENU(pd->prefs[bookmarks_filename_mode]));
+
 	integer_apply(&main_v->props.xhtml, pd->prefs[xhtml], TRUE);
+	if (main_v->props.xhtml) {
+		main_v->props.lowercase_tags = 1;
+		main_v->props.allow_dep = 0;
+	} else {
+		integer_apply(&main_v->props.lowercase_tags, pd->prefs[lowercase_tags], TRUE);
+		integer_apply(&main_v->props.allow_dep, pd->prefs[allow_dep], TRUE);
+	}
 	integer_apply(&main_v->props.auto_update_meta, pd->prefs[auto_update_meta], TRUE);
 	
 	string_apply(&main_v->props.newfile_default_encoding, GTK_COMBO(pd->prefs[newfile_default_encoding])->entry);
@@ -1635,8 +1754,8 @@ static void preferences_ok_clicked_lcb(GtkWidget *wid, Tprefdialog *pd) {
 	integer_apply(&main_v->props.restore_dimensions, pd->prefs[restore_dimensions], TRUE);
 	if (!main_v->props.restore_dimensions) {
 		integer_apply(&main_v->props.left_panel_width, pd->prefs[left_panel_width], FALSE);
-		integer_apply(&main_v->props.main_window_h, pd->prefs[main_window_h], FALSE);
-		integer_apply(&main_v->props.main_window_w, pd->prefs[main_window_w], FALSE);
+		integer_apply(&main_v->globses.main_window_h, pd->prefs[main_window_h], FALSE);
+		integer_apply(&main_v->globses.main_window_w, pd->prefs[main_window_w], FALSE);
 	}
 	string_apply(&main_v->props.tab_font_string, pd->prefs[tab_font_string]);
 	main_v->props.document_tabposition = gtk_option_menu_get_history(GTK_OPTION_MENU(pd->prefs[document_tabposition]));
@@ -1654,15 +1773,17 @@ static void preferences_ok_clicked_lcb(GtkWidget *wid, Tprefdialog *pd) {
 
 	string_apply(&main_v->props.default_basedir, pd->prefs[default_basedir]);
 	integer_apply(&main_v->props.filebrowser_two_pane_view, pd->prefs[filebrowser_two_pane_view], TRUE);
-	integer_apply(&main_v->props.filebrowser_show_hidden_files, pd->prefs[filebrowser_show_hidden_files], TRUE);
-	integer_apply(&main_v->props.filebrowser_show_backup_files, pd->prefs[filebrowser_show_backup_files], TRUE);
 	string_apply(&main_v->props.filebrowser_unknown_icon, pd->prefs[filebrowser_unknown_icon]);
 	string_apply(&main_v->props.filebrowser_dir_icon, pd->prefs[filebrowser_dir_icon]);
 	
 	string_apply(&main_v->props.image_thumbnailstring, pd->prefs[image_thumbnailstring]);
 	string_apply(&main_v->props.image_thumbnailtype, GTK_COMBO(pd->prefs[image_thumbnailtype])->entry);
 
-	filetype_apply_changes(pd);
+#ifdef HAVE_GNOME_VFS
+	integer_apply(&main_v->props.server_zope_compat, pd->prefs[server_zope_compat], TRUE);
+#endif
+
+	/*filetype_apply_changes(pd);*/
 	filefilter_apply_changes(pd);
 	highlightpattern_apply_changes(pd);
 	browsers_apply_changes(pd);
@@ -1670,24 +1791,23 @@ static void preferences_ok_clicked_lcb(GtkWidget *wid, Tprefdialog *pd) {
 	outputbox_apply_changes(pd);
 
 	free_arraylist(main_v->props.filetypes);
-	main_v->props.filetypes = pd->lists[filetypes];
+	main_v->props.filetypes = duplicate_arraylist(pd->lists[filetypes]);
 
 	free_arraylist(main_v->props.filefilters);
-	main_v->props.filefilters = pd->lists[filefilters];
+	main_v->props.filefilters = duplicate_arraylist(pd->lists[filefilters]);
 
 	free_arraylist(main_v->props.highlight_patterns);
-	main_v->props.highlight_patterns = pd->lists[highlight_patterns];
+	main_v->props.highlight_patterns = duplicate_arraylist(pd->lists[highlight_patterns]);
 	
 	free_arraylist(main_v->props.browsers);
-	main_v->props.browsers = pd->lists[browsers];
-	DEBUG_MSG("preferences_ok_clicked_lcb, new browsers list=%p\n", main_v->props.browsers);
+	main_v->props.browsers = duplicate_arraylist(pd->lists[browsers]);
 	
 	free_arraylist(main_v->props.external_commands);
-	main_v->props.external_commands = pd->lists[external_commands];
+	main_v->props.external_commands = duplicate_arraylist(pd->lists[external_commands]);
 	
 	free_arraylist(main_v->props.outputbox);
-	main_v->props.outputbox	 = pd->lists[outputbox];
-	
+	main_v->props.outputbox	 = duplicate_arraylist(pd->lists[outputbox]);
+
 	/* apply the changes to highlighting patterns and filetypes to the running program */
 	filetype_highlighting_rebuild();
 	filebrowser_filters_rebuild();
@@ -1709,20 +1829,16 @@ static void preferences_ok_clicked_lcb(GtkWidget *wid, Tprefdialog *pd) {
 			tmplist = g_list_next(tmplist);
 		}
 	}
+}
+
+static void preferences_cancel_clicked_lcb(GtkWidget *wid, Tprefdialog *pd) {
 	preferences_destroy_lcb(NULL, pd);
 }
-static void preferences_cancel_clicked_lcb(GtkWidget *wid, Tprefdialog *pd) {
-	DEBUG_MSG("preferences_cancel_clicked_lcb, started\n");
-	free_arraylist(pd->lists[filetypes]);
-	free_arraylist(pd->lists[filefilters]);
-	free_arraylist(pd->lists[highlight_patterns]);
-	free_arraylist(pd->lists[browsers]);
-	free_arraylist(pd->lists[external_commands]);
-	pd->lists[filetypes] = NULL;
-	pd->lists[filefilters] = NULL;
-	pd->lists[highlight_patterns] = NULL;
-	pd->lists[browsers] = NULL;
-	pd->lists[external_commands] = NULL;
+static void preferences_apply_clicked_lcb(GtkWidget *wid, Tprefdialog *pd) {
+	preferences_apply(pd);
+}
+static void preferences_ok_clicked_lcb(GtkWidget *wid, Tprefdialog *pd) {
+	preferences_apply(pd);
 	preferences_destroy_lcb(NULL, pd);
 }
 
@@ -1768,7 +1884,27 @@ static void preferences_dialog() {
 	pd->prefs[view_line_numbers] = boxed_checkbut_with_value(_("Line numbers by default"), main_v->props.view_line_numbers, vbox2);
 	pd->prefs[defaulthighlight] = boxed_checkbut_with_value(_("Highlight syntax by default"), main_v->props.defaulthighlight, vbox2);
 	pd->prefs[highlight_num_lines_count] = prefs_integer(_("Highlight # lines"), main_v->props.highlight_num_lines_count, vbox2, pd, 1, 8);
-	pd->prefs[cont_highlight_full] = boxed_checkbut_with_value(_("Always highlight full document"), main_v->props.cont_highlight_full, vbox2);
+
+	frame = gtk_frame_new(_("Undo"));
+	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 5);
+	vbox2 = gtk_vbox_new(FALSE, 0);
+	gtk_container_add(GTK_CONTAINER(frame), vbox2);
+
+	pd->prefs[num_undo_levels] = prefs_integer(_("Undo history size"), main_v->props.num_undo_levels, vbox2, pd, 50, 10000);
+	pd->prefs[clear_undo_on_save] = boxed_checkbut_with_value(_("Clear undo history on save"), main_v->props.clear_undo_on_save, vbox2);
+	
+	frame = gtk_frame_new(_("Bookmark options"));
+	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 5);
+	vbox2 = gtk_vbox_new(FALSE, 0);
+	gtk_container_add(GTK_CONTAINER(frame), vbox2);
+	
+	pd->prefs[bookmarks_sort] = boxed_checkbut_with_value(_("Sort by line number"), main_v->props.bookmarks_sort, vbox2);
+	pd->prefs[bookmarks_default_store] = boxed_checkbut_with_value(_("Make permanent by default"), main_v->props.bookmarks_default_store, vbox2);
+	{
+		gchar *actions[] = {N_("full path"), N_("path from basedir"), N_("filename"), NULL};
+		pd->prefs[bookmarks_filename_mode] = boxed_optionmenu_with_value(_("Bookmarks filename display"), main_v->props.bookmarks_filename_mode, vbox2, actions);
+	}
+
 	vbox1 = gtk_vbox_new(FALSE, 5);
 	gtk_notebook_append_page(GTK_NOTEBOOK(pd->noteb), vbox1, hbox_with_pix_and_text(_("HTML"),154,TRUE));
 
@@ -1816,14 +1952,6 @@ static void preferences_dialog() {
 	create_backup_toggled_lcb(GTK_TOGGLE_BUTTON(pd->prefs[backup_file]), pd);
 	g_signal_connect(G_OBJECT(pd->prefs[backup_file]), "toggled", G_CALLBACK(create_backup_toggled_lcb), pd);
 
-	frame = gtk_frame_new(_("Undo"));
-	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 5);
-	vbox2 = gtk_vbox_new(FALSE, 0);
-	gtk_container_add(GTK_CONTAINER(frame), vbox2);
-
-	pd->prefs[num_undo_levels] = prefs_integer(_("Undo history size"), main_v->props.num_undo_levels, vbox2, pd, 50, 10000);
-	pd->prefs[clear_undo_on_save] = boxed_checkbut_with_value(_("Clear undo history on save"), main_v->props.clear_undo_on_save, vbox2);
-
 	frame = gtk_frame_new(_("Misc"));
 	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 5);
 	vbox2 = gtk_vbox_new(FALSE, 0);
@@ -1836,6 +1964,15 @@ static void preferences_dialog() {
 	pd->prefs[modified_check_type] = boxed_optionmenu_with_value(_("File modified on disk check "), main_v->props.modified_check_type, vbox2, modified_check_types);
 	pd->prefs[max_recent_files] = prefs_integer(_("Number of files in 'Open recent'"), main_v->props.max_recent_files, vbox2, pd, 3, 100);
 
+	frame = gtk_frame_new(_("File browser"));
+	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 5);
+	vbox2 = gtk_vbox_new(FALSE, 0);
+	gtk_container_add(GTK_CONTAINER(frame), vbox2);
+	pd->prefs[default_basedir] = prefs_string(_("Default basedir"), main_v->props.default_basedir, vbox2, pd, string_none);
+	pd->prefs[filebrowser_two_pane_view] = boxed_checkbut_with_value(_("Use separate file and directory view"), main_v->props.filebrowser_two_pane_view, vbox2);
+	pd->prefs[filebrowser_unknown_icon] = prefs_string(_("Unknown icon"), main_v->props.filebrowser_unknown_icon, vbox2, pd, string_file);
+	pd->prefs[filebrowser_dir_icon] = prefs_string(_("Directory icon"), main_v->props.filebrowser_dir_icon, vbox2, pd, string_file);
+
 	vbox1 = gtk_vbox_new(FALSE, 5);
 	gtk_notebook_append_page(GTK_NOTEBOOK(pd->noteb), vbox1, hbox_with_pix_and_text(_("User interface"), 156,TRUE));
 
@@ -1845,8 +1982,8 @@ static void preferences_dialog() {
 	gtk_container_add(GTK_CONTAINER(frame), vbox2);
 	pd->prefs[restore_dimensions] = boxed_checkbut_with_value(_("Restore last used dimensions"), main_v->props.restore_dimensions, vbox2);
 	pd->prefs[left_panel_width] = prefs_integer(_("Initial left panel width"), main_v->props.left_panel_width, vbox2, pd, 1, 4000);
-	pd->prefs[main_window_h] = prefs_integer(_("Initial window height"), main_v->props.main_window_h, vbox2, pd, 1, 4000);
-	pd->prefs[main_window_w] = prefs_integer(_("Initial window width"), main_v->props.main_window_w, vbox2, pd, 1, 4000);
+	pd->prefs[main_window_h] = prefs_integer(_("Initial window height"), main_v->globses.main_window_h, vbox2, pd, 1, 4000);
+	pd->prefs[main_window_w] = prefs_integer(_("Initial window width"), main_v->globses.main_window_w, vbox2, pd, 1, 4000);
 	restore_dimensions_toggled_lcb(GTK_TOGGLE_BUTTON(pd->prefs[restore_dimensions]), pd);
 	g_signal_connect(G_OBJECT(pd->prefs[restore_dimensions]), "toggled", G_CALLBACK(restore_dimensions_toggled_lcb), pd);
 
@@ -1870,18 +2007,6 @@ static void preferences_dialog() {
 	pd->prefs[document_tabposition] = boxed_optionmenu_with_value(_("Document notebook tab position"), main_v->props.document_tabposition, vbox2, notebooktabpositions);
 	pd->prefs[leftpanel_tabposition] = boxed_optionmenu_with_value(_("Left panel notebook tab position"), main_v->props.leftpanel_tabposition, vbox2, notebooktabpositions);
 
-
-	frame = gtk_frame_new(_("File browser"));
-	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 5);
-	vbox2 = gtk_vbox_new(FALSE, 0);
-	gtk_container_add(GTK_CONTAINER(frame), vbox2);
-	pd->prefs[default_basedir] = prefs_string(_("Default basedir"), main_v->props.default_basedir, vbox2, pd, string_none);
-	pd->prefs[filebrowser_two_pane_view] = boxed_checkbut_with_value(_("Use separate file and directory view"), main_v->props.filebrowser_two_pane_view, vbox2);
-	pd->prefs[filebrowser_show_hidden_files] = boxed_checkbut_with_value(_("Show hidden files"), main_v->props.filebrowser_show_hidden_files, vbox2);
-	pd->prefs[filebrowser_show_backup_files] = boxed_checkbut_with_value(_("Show backup files"), main_v->props.filebrowser_show_backup_files, vbox2);
-	pd->prefs[filebrowser_unknown_icon] = prefs_string(_("Unknown icon"), main_v->props.filebrowser_unknown_icon, vbox2, pd, string_file);
-	pd->prefs[filebrowser_dir_icon] = prefs_string(_("Directory icon"), main_v->props.filebrowser_dir_icon, vbox2, pd, string_file);
-
 	vbox1 = gtk_vbox_new(FALSE, 5);
 	gtk_notebook_append_page(GTK_NOTEBOOK(pd->noteb), vbox1, hbox_with_pix_and_text(_("Images"), 155,TRUE));
 
@@ -1950,7 +2075,18 @@ static void preferences_dialog() {
 	gtk_container_add(GTK_CONTAINER(frame), vbox2);
 	
 	create_outputbox_gui(pd, vbox2);
+
+#ifdef HAVE_GNOME_VFS
+	vbox1 = gtk_vbox_new(FALSE, 5);
+	gtk_notebook_append_page(GTK_NOTEBOOK(pd->noteb), vbox1, hbox_with_pix_and_text(_("Servers"), 0,TRUE));
 	
+	frame = gtk_frame_new(_("Remote servers"));
+	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 5);
+	vbox2 = gtk_vbox_new(FALSE, 0);
+	gtk_container_add(GTK_CONTAINER(frame), vbox2);
+	
+	pd->prefs[server_zope_compat] = boxed_checkbut_with_value(_("Zope compatibility mode"), main_v->props.server_zope_compat, vbox2);
+#endif
 
 	/* end, create buttons for dialog now */
 	{
@@ -1960,11 +2096,13 @@ static void preferences_dialog() {
 		gtk_button_box_set_spacing(GTK_BUTTON_BOX(ahbox), 1);
 
 		gtk_box_pack_start(GTK_BOX(dvbox), ahbox, FALSE, FALSE, 0);
-
-		but = bf_stock_cancel_button(GTK_SIGNAL_FUNC(preferences_cancel_clicked_lcb), pd);
+		but = bf_gtkstock_button(GTK_STOCK_APPLY, G_CALLBACK(preferences_apply_clicked_lcb), pd);
 		gtk_box_pack_start(GTK_BOX(ahbox), but, TRUE, TRUE, 0);
 
-		but = bf_stock_ok_button(GTK_SIGNAL_FUNC(preferences_ok_clicked_lcb), pd);
+		but = bf_stock_cancel_button(G_CALLBACK(preferences_cancel_clicked_lcb), pd);
+		gtk_box_pack_start(GTK_BOX(ahbox), but, TRUE, TRUE, 0);
+
+		but = bf_stock_ok_button(G_CALLBACK(preferences_ok_clicked_lcb), pd);
 		gtk_box_pack_start(GTK_BOX(ahbox), but, TRUE, TRUE, 0);
 		gtk_window_set_default(GTK_WINDOW(pd->win), but);
 	}
