@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * project.c - project functionality
  *
- * Copyright (C) 2003 Olivier Sessink
+ * Copyright (C) 2003-2004 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,6 +33,22 @@
 #include "bf_lib.h"
 #include "filebrowser.h"
 #include "menu.h"
+#include "bookmark.h"
+
+static void free_session(Tsessionvars *session) {
+	free_stringlist(session->classlist);
+	free_stringlist(session->colorlist);
+	free_stringlist(session->targetlist);
+	free_stringlist(session->urllist);
+	free_stringlist(session->fontlist);
+	free_stringlist(session->dtd_cblist);
+	free_stringlist(session->headerlist);
+	free_stringlist(session->positionlist);
+	free_stringlist(session->searchlist);
+	free_stringlist(session->replacelist);
+	free_arraylist(session->bmarks);
+	g_free(session);
+}
 
 Tbfwin *project_is_open(gchar *filename) {
 	GList *tmplist;
@@ -55,19 +71,30 @@ static void update_project_filelist(Tbfwin *bfwin, Tproject *prj) {
 	prj->files = return_filenamestringlist_from_doclist(bfwin->documentlist);
 }
 
+static void setup_bfwin_for_project(Tbfwin *bfwin) {
+	bfwin->session = bfwin->project->session;
+	bfwin->bookmarkstore = bfwin->project->bookmarkstore;
+	bmark_set_store(bfwin);
+	filebrowser_set_basedir(bfwin, bfwin->project->basedir);
+	recent_menu_from_list(bfwin, bfwin->project->session->recent_files, FALSE);
+	set_project_menu_widgets(bfwin, TRUE);
+}
+
 /* bfwin is allowed to be NULL for an empty project */
 static Tproject *create_new_project(Tbfwin *bfwin) {
 	Tproject *prj;
 	prj = g_new0(Tproject,1);
 	prj->name = g_strdup(_("New project"));
+	prj->bookmarkstore = gtk_tree_store_new(2, G_TYPE_STRING, G_TYPE_POINTER); 
+	DEBUG_MSG("create_new_project, project=%p, bookmarkstore=%p, bfwin=%p\n",prj,prj->bookmarkstore,bfwin);
 	if (bfwin) {
 		DEBUG_MSG("create_new_project, new project for bfwin %p\n",bfwin);
 		update_project_filelist(bfwin,prj);
-		prj->session = bfwin->session;
+		bfwin->project = prj;
 	} else {
 		DEBUG_MSG("create_new_project, new project, no bfwin\n");
-		prj->session = g_new0(Tsessionvars,1);
 	}
+	prj->session = g_new0(Tsessionvars,1);
 	if (prj->files) {
 		gint len;
 		gchar *somefile, *prefix;
@@ -90,6 +117,9 @@ static Tproject *create_new_project(Tbfwin *bfwin) {
 	prj->view_custom_menu = main_v->props.view_custom_menu;
 	prj->view_html_toolbar = main_v->props.view_html_toolbar;
 	prj->word_wrap = main_v->props.word_wrap;
+	if (bfwin) {
+		setup_bfwin_for_project(bfwin);
+	}
 	return prj;
 }
 
@@ -100,13 +130,15 @@ gboolean project_save(Tbfwin *bfwin, gboolean save_as) {
 		/* there is no project yet, we have to create one */
 		DEBUG_MSG("project_save, bfwin=%p does not have a project yet, create one\n",bfwin);
 		bfwin->project= create_new_project(bfwin);
+  	   bmark_reload(bfwin);
 	}
 	DEBUG_MSG("project_save, project=%p, num files was %d\n", bfwin->project, g_list_length(bfwin->project->files));
 	update_project_filelist(bfwin, bfwin->project);
-	bfwin->project->recentfiles = limit_stringlist(bfwin->project->recentfiles, main_v->props.max_recent_files, TRUE);
+/*	bfwin->project->recentfiles = limit_stringlist(bfwin->project->recentfiles, main_v->props.max_recent_files, TRUE);*/
 	
 	bfwin->project->session->searchlist = limit_stringlist(bfwin->project->session->searchlist, 10, TRUE);
 	bfwin->project->session->replacelist = limit_stringlist(bfwin->project->session->replacelist, 10, TRUE);
+	bmark_store_all(bfwin);
 
 	if (save_as || bfwin->project->filename == NULL) {
 		gchar *filename = return_file_w_title(NULL, _("Enter Bluefish project filename"));
@@ -135,7 +167,7 @@ void set_project_menu_widgets(Tbfwin *bfwin, gboolean win_has_project) {
 	ifactory = gtk_item_factory_from_widget(bfwin->menubar);
 	gtk_widget_set_sensitive(gtk_item_factory_get_widget(ifactory, _("/Project/Save")), win_has_project);
 	gtk_widget_set_sensitive(gtk_item_factory_get_widget(ifactory, _("/Project/Save as...")), win_has_project);
-	gtk_widget_set_sensitive(gtk_item_factory_get_widget(ifactory, _("/Project/Close & save")), win_has_project);
+	gtk_widget_set_sensitive(gtk_item_factory_get_widget(ifactory, _("/Project/Save & close")), win_has_project);
 	gtk_widget_set_sensitive(gtk_item_factory_get_widget(ifactory, _("/Project/Edit Project Options...")), win_has_project);
 }
 
@@ -154,6 +186,7 @@ void project_open_from_file(Tbfwin *bfwin, gchar *fromfilename) {
 
 	prj = g_new0(Tproject,1);
 	prj->session = g_new0(Tsessionvars,1);
+	prj->bookmarkstore = gtk_tree_store_new(2, G_TYPE_STRING, G_TYPE_POINTER); 
 	retval = rcfile_parse_project(prj, fromfilename);
 	if (!retval) {
 		DEBUG_MSG("project_open_from_file, failed parsing the project at file %s\n",fromfilename);
@@ -167,16 +200,18 @@ void project_open_from_file(Tbfwin *bfwin, gchar *fromfilename) {
 		/* we will use this Bluefish window to open the project */
 		prwin = bfwin;
 		/* now we need to clean the session, and reset it to the session from the project */
-		free_session(bfwin->session);
+		/* free_session(bfwin->session); there is no session specific to a window anymore, only a global one*/
 		bfwin->session = prj->session;
-		DEBUG_MSG("project_open_from_file, calling docs_new_from_files for existing bfwin=%p\n",prwin);
 		prwin->project = prj;
+		prwin->bookmarkstore = prj->bookmarkstore;
 		
 		gui_set_html_toolbar_visible(prwin, prj->view_html_toolbar, TRUE);
 		gui_set_main_toolbar_visible(prwin, prj->view_main_toolbar, TRUE);
 		gui_set_custom_menu_visible(prwin, prj->view_custom_menu, TRUE);
+		DEBUG_MSG("project_open_from_file, calling left_panel_show_hide_toggle bfwin=%p\n",prwin);
 		left_panel_show_hide_toggle(prwin,FALSE,prj->view_left_panel, TRUE);
 		filebrowser_set_basedir(prwin, prj->basedir);
+		DEBUG_MSG("project_open_from_file, calling docs_new_from_files for existing bfwin=%p\n",prwin);
 		docs_new_from_files(prwin, prj->files, TRUE);
 	} else {
 		/* we will open a new Bluefish window for this project */
@@ -185,8 +220,11 @@ void project_open_from_file(Tbfwin *bfwin, gchar *fromfilename) {
 		DEBUG_MSG("project_open_from_file, new window with files ready\n");
 		gui_set_title(prwin, prwin->current_document);
 	}
+
 	set_project_menu_widgets(prwin, TRUE);
 	recent_menu_init_project(prwin);
+   bmark_reload(bfwin);
+   bmark_set_store(bfwin);
 }
 
 static void project_open(Tbfwin *bfwin) {
@@ -202,6 +240,7 @@ static void project_open(Tbfwin *bfwin) {
 }
 
 static void project_destroy(Tproject *project) {
+	g_object_unref(G_OBJECT(project->bookmarkstore));
 	free_stringlist(project->files);
 	free_session(project->session);
 	g_free(project->filename);
@@ -212,6 +251,17 @@ static void project_destroy(Tproject *project) {
 	g_free(project);
 }
 
+static void setup_bfwin_for_nonproject(Tbfwin *bfwin) {
+	bfwin->session = main_v->session;
+	bfwin->bookmarkstore = main_v->bookmarkstore;
+	bfwin->project = NULL;
+	bmark_set_store(bfwin);
+	gui_set_title(bfwin, bfwin->current_document);
+	filebrowser_set_basedir(bfwin, NULL);
+	recent_menu_from_list(bfwin, main_v->session->recent_files, FALSE);
+	set_project_menu_widgets(bfwin, FALSE);
+}
+
 gboolean project_save_and_close(Tbfwin *bfwin) {
 	if (project_save(bfwin, FALSE)) {
 		DEBUG_MSG("project_save_and_close, save returned TRUE\n");
@@ -220,13 +270,7 @@ gboolean project_save_and_close(Tbfwin *bfwin) {
 			DEBUG_MSG("project_save_and_close, all documents are closed\n");
 			add_to_recent_list(bfwin,bfwin->project->filename, TRUE, TRUE);
 			project_destroy(bfwin->project);
-			/* the window gets a new fresh session */
-			bfwin->session = g_new0(Tsessionvars,1);
-			bfwin->project = NULL;
-			gui_set_title(bfwin, bfwin->current_document);
-			filebrowser_set_basedir(bfwin, NULL);
-			recent_menu_from_file(bfwin, "/.bluefish/recentlist", FALSE);
-			set_project_menu_widgets(bfwin, FALSE);
+			setup_bfwin_for_nonproject(bfwin);
 			DEBUG_MSG("project_save_and_close, returning TRUE\n");
 			return TRUE;
 		}
@@ -249,12 +293,18 @@ typedef struct {
 	Tbfwin *bfwin;
 	Tproject *project;
 	GtkWidget *entries[projecteditor_entries_num];
-	gboolean project_created_by_editor;
+	gboolean destroy_project_on_close;
 } Tprojecteditor;
 
 static void project_edit_destroy_lcb(GtkWidget *widget, Tprojecteditor *pred) {
 	DEBUG_MSG("project_edit_destroy_lcb, called for pred=%p\n",pred);
 /*	gtk_widget_destroy(pred->win);*/
+	if (pred->destroy_project_on_close) {
+		project_destroy(pred->project);
+		if (pred->bfwin) {
+			setup_bfwin_for_nonproject(pred->bfwin);
+		}
+	}
 	if (pred->project) {
 		pred->project->editor = NULL;
 	}
@@ -262,26 +312,16 @@ static void project_edit_destroy_lcb(GtkWidget *widget, Tprojecteditor *pred) {
 }
 
 static void project_edit_cancel_clicked_lcb(GtkWidget *widget, Tprojecteditor *pred) {
-	if (pred->project_created_by_editor) {
-		DEBUG_MSG("project_edit_cancel_clicked_lcb, destroy project\n");
-		project_destroy(pred->project);
-		if (pred->bfwin) {
-			pred->bfwin->project = NULL;
-			pred->bfwin->session = g_new0(Tsessionvars,1);
-		}
-	}
 	gtk_widget_destroy(pred->win);
 }
 
 static void project_edit_ok_clicked_lcb(GtkWidget *widget, Tprojecteditor *pred) {
-	gchar *oldbasedir;
 	Tproject *prj = pred->project;
+	
+	pred->destroy_project_on_close = FALSE;
+	
 	gtk_widget_hide(pred->win);
-	if (pred->bfwin == NULL) {
-		pred->bfwin = gui_new_window(NULL, pred->project);
-	}
 	DEBUG_MSG("project_edit_ok_clicked_lcb, Tproject at %p, bfwin at %p\n",prj,pred->bfwin);
-	oldbasedir = g_strdup(prj->basedir);
 	string_apply(&prj->name, pred->entries[name]);
 	string_apply(&prj->basedir, pred->entries[basedir]);
 	if (prj->basedir && strlen(prj->basedir)) {
@@ -293,12 +333,14 @@ static void project_edit_ok_clicked_lcb(GtkWidget *widget, Tprojecteditor *pred)
 	string_apply(&prj->template, pred->entries[template]);
 	integer_apply(&prj->word_wrap, pred->entries[word_wrap], TRUE);
 	DEBUG_MSG("project_edit_ok_clicked_lcb, name=%s, basedir=%s, webdir=%s\n",prj->name,prj->basedir,prj->webdir);
-	if (strcmp(prj->basedir, oldbasedir)!=0 && strlen(prj->basedir) > 2) {
-		filebrowser_set_basedir(pred->bfwin, prj->basedir);
+
+	if (pred->bfwin == NULL) {
+		pred->bfwin = gui_new_window(NULL, pred->project);
+		setup_bfwin_for_project(pred->bfwin);
+	} else {
+		gui_set_title(pred->bfwin, pred->bfwin->current_document);
 	}
-	g_free(oldbasedir);
-	gui_set_title(pred->bfwin, pred->bfwin->current_document);
-	set_project_menu_widgets(pred->bfwin, TRUE);
+/* set_project_menu_widgets(pred->bfwin, TRUE);*/
 	project_save(pred->bfwin,FALSE);
 	gtk_widget_destroy(pred->win);
 }
@@ -323,10 +365,11 @@ void project_edit(Tbfwin *bfwin) {
 		if (bfwin) {
 			bfwin->project = pred->project;
 		}
-		pred->project_created_by_editor = TRUE;
+		/* id the user does not press OK, we destroy the project */
+		pred->destroy_project_on_close = TRUE;
 		wintitle = g_strdup(_("Create New Project"));
 	} else {
-		pred->project_created_by_editor = FALSE;
+		pred->destroy_project_on_close = FALSE;
 		wintitle = g_strdup(_("Edit Project"));
 		if (bfwin) {
 			pred->project = bfwin->project;
@@ -355,7 +398,7 @@ void project_edit(Tbfwin *bfwin) {
 		g_free(message);
 	}
 	
-	table = gtk_table_new (5, 3, FALSE);
+	table = gtk_table_new (5, 4, FALSE);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 6);	
 	gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 12);
@@ -366,16 +409,18 @@ void project_edit(Tbfwin *bfwin) {
 	gtk_table_attach_defaults(GTK_TABLE(table), pred->entries[name], 2, 3, 0, 1);
 
 	pred->entries[basedir] = entry_with_text(pred->project->basedir, 255);
-	bf_mnemonic_label_tad_with_alignment(_("_Local Directory:"), pred->entries[basedir], 1, 0.5, table, 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Basedir:"), pred->entries[basedir], 1, 0.5, table, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(table), pred->entries[basedir], 2, 3, 1, 2);
 
 	pred->entries[webdir] = entry_with_text(pred->project->webdir, 255);
-	bf_mnemonic_label_tad_with_alignment(_("_Remote Directory:"), pred->entries[webdir], 1, 0.5, table, 0, 1, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("_Preview URL:"), pred->entries[webdir], 1, 0.5, table, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(table), pred->entries[webdir], 2, 3, 2, 3);
 	
 	pred->entries[template] = entry_with_text(pred->project->template, 255);
 	bf_mnemonic_label_tad_with_alignment(_("_Template:"), pred->entries[template], 1, 0.5, table, 0, 1, 3, 4);
-	gtk_table_attach_defaults(GTK_TABLE(table), pred->entries[template], 2, 3, 3, 4);	
+	but = file_but_new(pred->entries[template], 1, NULL);
+	gtk_table_attach_defaults(GTK_TABLE(table), pred->entries[template], 2, 3, 3, 4);
+	gtk_table_attach_defaults(GTK_TABLE(table), but, 3, 4, 3, 4);
 
 	gtk_table_set_row_spacing(GTK_TABLE(table), 3, 18);
 	pred->entries[word_wrap] = checkbut_with_value(_("_Word wrap by default"), pred->project->word_wrap);
@@ -388,8 +433,8 @@ void project_edit(Tbfwin *bfwin) {
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	but = bf_stock_cancel_button(G_CALLBACK(project_edit_cancel_clicked_lcb), pred);
 	gtk_box_pack_start(GTK_BOX(hbox), but, FALSE, FALSE, 0);
-	if (pred->project_created_by_editor == TRUE) {
-		but = bf_generic_button_with_image(_("Create _Project"), 0, G_CALLBACK(project_edit_ok_clicked_lcb), pred);
+	if (pred->destroy_project_on_close == TRUE) {
+		but = bf_allbuttons_backend(_("Create _Project"), 1, 0, G_CALLBACK(project_edit_ok_clicked_lcb), pred);
 	} else {
 		but = bf_stock_ok_button(G_CALLBACK(project_edit_ok_clicked_lcb), pred);
 	}
