@@ -33,6 +33,7 @@
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <string.h>  	/* strspn() */
+#include <strings.h>  	/* strcasecmp() */
 #include "bluefish.h"
 #include "bf_lib.h"
 
@@ -396,7 +397,7 @@ void estrl_dialog(GList **which_list, gchar *title, gint what_list
 	  wx += optx + gtk_clist_optimal_column_width(GTK_CLIST(estrl->clist), 1);
 	  if( wx < gdk_screen_width() ) {
 	    gtk_clist_set_column_width(GTK_CLIST(estrl->clist), 0, optx );
-	    gtk_widget_set_usize(GTK_WIDGET(estrl->win), wx, 400);
+	    gtk_widget_set_size_request(GTK_WIDGET(estrl->win), wx, 400);
 	    gtk_widget_set_uposition(estrl->win, 
 				     (gdk_screen_width()-wx)/2,
 				     (gdk_screen_height() - 400)/2);
@@ -627,6 +628,28 @@ gchar **array_from_arglist(const gchar *string1, ...) {
 	*index = NULL;
 	return retval;
 }
+/**
+ * array_from_arglist:
+ * @allocate_strings: #gboolean if the strings should be newly allocated
+ * @...: #gchar* with the first string, NULL terminated
+ *
+ * builds a GList with strings (a stringlist), copied by reference or by content
+ *
+ * Return value: GList *
+ */
+GList *list_from_arglist(gboolean allocate_strings, ...) {
+	GList *retval=NULL;
+	va_list args;
+	gchar *s;
+	va_start(args, allocate_strings);
+	s = va_arg(args, gchar*);
+	while (s) {
+		retval = g_list_append(retval, s);
+		s = va_arg (args, gchar*);
+	}
+	va_end (args);
+	return retval;
+}
 
 GList *duplicate_stringlist(GList *list, gint dup_data) {
 	GList *retlist=NULL;
@@ -949,6 +972,7 @@ gchar *stringlist_to_string(GList *stringlist, gchar *delimiter) {
  * @arraylist: #GList*
  * @value: #gchar**
  * @testlevel: #gint
+ * @case_sensitive: #gboolean whether the test should be case sensitive
  *
  * tests for the occurence of an array with identical content as value
  * in arraylist. It will only test the first testlevel strings in the array
@@ -957,7 +981,7 @@ gchar *stringlist_to_string(GList *stringlist, gchar *delimiter) {
  *
  * Return value: #gboolean 
  */
-gboolean arraylist_value_exists(GList *arraylist, gchar **value, gint testlevel) {
+gboolean arraylist_value_exists(GList *arraylist, gchar **value, gint testlevel, gboolean case_sensitive) {
 	GList *tmplist = g_list_first(arraylist);
 	while (tmplist) {
 		gchar **tmparr = tmplist->data;
@@ -967,7 +991,9 @@ gboolean arraylist_value_exists(GList *arraylist, gchar **value, gint testlevel)
 			/*  tmparr[i]==value[i] will only happen when they are both NULL	*/
 			if (tmparr[i] == NULL && value[i] == NULL) {
 				break;
-			} else if (tmparr[i]==NULL || value[i] == NULL || strcmp(tmparr[i],value[i])!=0) {
+			} else if (tmparr[i]==NULL || value[i] == NULL 
+					|| (case_sensitive && strcmp(tmparr[i],value[i])!=0) 
+					|| (!case_sensitive && strcasecmp(tmparr[i],value[i])!=0)) {
 				equal = FALSE;
 			}
 			i++;
@@ -996,7 +1022,7 @@ GList *arraylist_load_new_identifiers_from_list(GList *mylist, GList *deflist, g
 	while (tmplist) {
 		gchar **tmparr = tmplist->data;
 		if (count_array(tmparr) >= uniquelevel) {
-			if (!arraylist_value_exists(mylist, tmparr, uniquelevel)) {
+			if (!arraylist_value_exists(mylist, tmparr, uniquelevel, TRUE)) {
 				DEBUG_MSG("arraylist_load_new_identifiers, adding %s to thelist\n",tmparr[0]);
 				mylist = g_list_append(mylist, duplicate_stringarray(tmparr));
 			}
